# encoding=utf8
from niapy.algorithms.basic import GreyWolfOptimizer
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class GWOTestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = GreyWolfOptimizer

    def test_custom(self):
        gwo_custom = self.algo(population_size=10, seed=self.seed)
        gwo_customc = self.algo(population_size=10, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, gwo_custom, gwo_customc, MyProblem())

    def test_griewank(self):
        gwo_griewank = self.algo(population_size=10, seed=self.seed)
        gwo_griewankc = self.algo(population_size=10, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, gwo_griewank, gwo_griewankc)



# encoding=utf8

from unittest import TestCase

from niapy.algorithms.basic import BatAlgorithm, FireflyAlgorithm
from niapy.algorithms.basic import DifferentialEvolution
from niapy.problems import Sphere
from niapy.task import Task


class DETestCase(TestCase):

    def test_DE_evals(self):
        task = Task(max_evals=1000, problem=Sphere(10))
        algo = DifferentialEvolution(population_size=10, CR=0.9, F=0.5)
        algo.run_task(task)
        evals = task.evals
        self.assertEqual(1000, evals)

    def test_DE_iters(self):
        task = Task(max_iters=1000, problem=Sphere(10))
        algo = DifferentialEvolution(population_size=10, CR=0.9, F=0.5)
        algo.run_task(task)
        iters = task.iters
        self.assertEqual(1000, iters)


class BATestCase(TestCase):

    def test_BA_evals(self):
        task = Task(max_evals=1000, problem=Sphere(10))
        algo = BatAlgorithm(population_size=10)
        algo.run_task(task)
        evals = task.evals
        self.assertEqual(1000, evals)

    def test_BA_iters(self):
        task = Task(max_iters=1000, problem=Sphere(10))
        algo = BatAlgorithm(population_size=10)
        algo.run_task(task)
        iters = task.iters
        self.assertEqual(1000, iters)

    # 1000 BA iterations spend 10010 FES (10 + 10 * 1000)
    def test_BA_iters_to_fes(self):
        task = Task(max_iters=1000, problem=Sphere(10))
        algo = BatAlgorithm(population_size=10)
        algo.run_task(task)
        evals = task.evals
        self.assertEqual(10010, evals)


class FATestCase(TestCase):

    def test_FA_evals(self):
        task = Task(max_evals=1000, problem=Sphere(10))
        algo = FireflyAlgorithm(population_size=10)
        algo.run_task(task)
        evals = task.evals
        self.assertEqual(1000, evals)

    def test_FA_iters(self):
        task = Task(max_iters=1000, problem=Sphere(10))
        algo = FireflyAlgorithm(population_size=10)
        algo.run_task(task)
        iters = task.iters
        self.assertEqual(1000, iters)



# encoding=utf8
from niapy.algorithms.other import AnarchicSocietyOptimization
from niapy.algorithms.other.aso import elitism, sequential, crossover
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class ASOTestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = AnarchicSocietyOptimization


class ASOElitismTestCase(ASOTestCase):
    def test_custom(self):
        aso_custom = self.algo(population_size=10, combination=elitism, seed=self.seed)
        aso_customc = self.algo(population_size=10, combination=elitism, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, aso_custom, aso_customc, MyProblem())

    def test_griewank(self):
        aso_griewank = self.algo(population_size=10, combination=elitism, seed=self.seed)
        aso_griewankc = self.algo(population_size=10, combination=elitism, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, aso_griewank, aso_griewankc)


class ASOSequentialTestCase(AlgorithmTestCase):
    def test_custom(self):
        aso_custom = self.algo(population_size=10, combination=sequential, seed=self.seed)
        aso_customc = self.algo(population_size=10, combination=sequential, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, aso_custom, aso_customc, MyProblem())

    def test_griewank(self):
        aso_griewank = self.algo(population_size=10, combination=sequential, seed=self.seed)
        aso_griewankc = self.algo(population_size=10, combination=sequential, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, aso_griewank, aso_griewankc)


class ASOCrossoverTestCase(AlgorithmTestCase):
    def test_custom(self):
        aso_custom = self.algo(population_size=10, combination=crossover, seed=self.seed)
        aso_customc = self.algo(population_size=10, combination=crossover, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, aso_custom, aso_customc, MyProblem())

    def test_griewank(self):
        aso_griewank = self.algo(population_size=10, combination=crossover, seed=self.seed)
        aso_griewankc = self.algo(population_size=10, combination=crossover, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, aso_griewank, aso_griewankc)

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



# encoding=utf8
from niapy.algorithms.basic import SineCosineAlgorithm
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class SCATestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = SineCosineAlgorithm

    def test_algorithm_info(self):
        self.assertIsNotNone(self.algo.info())

    def test_custom(self):
        sca_custom = self.algo(population_size=35, a=7, r_min=0.1, r_max=3, seed=self.seed)
        sca_customc = self.algo(population_size=35, a=7, r_min=0.1, r_max=3, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, sca_custom, sca_customc, MyProblem())

    def test_griewank(self):
        sca_griewank = self.algo(population_size=10, a=5, r_min=0.01, r_max=3, seed=self.seed)
        sca_griewankc = self.algo(population_size=10, a=5, r_min=0.01, r_max=3, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, sca_griewank, sca_griewankc)

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



# encoding=utf8
from niapy.algorithms.basic import FlowerPollinationAlgorithm
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class FPATestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = FlowerPollinationAlgorithm

    def test_custom(self):
        fpa_custom = self.algo(population_size=10, p=0.5, seed=self.seed)
        fpa_customc = self.algo(population_size=10, p=0.5, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, fpa_custom, fpa_customc, MyProblem())

    def test_griewank(self):
        fpa_griewank = self.algo(population_size=10, p=0.5, seed=self.seed)
        fpa_griewankc = self.algo(population_size=10, p=0.5, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, fpa_griewank, fpa_griewankc)

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



# encoding=utf8
from niapy.algorithms.basic import BeesAlgorithm
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class BEATestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = BeesAlgorithm

    def test_custom(self):
        bea = self.algo(population_size=10, m=5, e=4, nep=5, nsp=5, ngh=2, seed=self.seed)
        beac = self.algo(population_size=10, m=5, e=4, nep=5, nsp=5, ngh=2, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, bea, beac, MyProblem())

    def test_griewank(self):
        bea_griewank = self.algo(population_size=10, m=5, e=4, nep=5, nsp=5, ngh=2, seed=self.seed)
        bea_griewankc = self.algo(population_size=10, m=5, e=4, nep=5, nsp=5, ngh=2, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, bea_griewank, bea_griewankc)

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



# encoding=utf8

from niapy.algorithms.basic import BacterialForagingOptimization
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class BFOTestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = BacterialForagingOptimization

    def test_custom(self):
        bfoa_custom = self.algo(population_size=10, n_chemotactic=100, n_reproduction=4, n_elimination=1, step_size=0.1,
                                seed=self.seed)
        bfoa_customc = self.algo(population_size=10, n_chemotactic=100, n_reproduction=4, n_elimination=1,
                                 step_size=0.1, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, bfoa_custom, bfoa_customc, MyProblem())

    def test_griewank(self):
        bfoa_custom = self.algo(population_size=10, n_chemotactic=100, n_reproduction=4, n_elimination=1, step_size=0.1,
                                seed=self.seed)
        bfoa_customc = self.algo(population_size=10, n_chemotactic=100, n_reproduction=4, n_elimination=1,
                                 step_size=0.1, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, bfoa_custom, bfoa_customc)

    def test_griewank_nfes(self):
        bfoa_custom = self.algo(population_size=10, n_chemotactic=100, n_reproduction=4, n_elimination=1, step_size=0.1,
                                seed=self.seed)
        bfoa_customc = self.algo(population_size=10, n_chemotactic=100, n_reproduction=4, n_elimination=1,
                                 step_size=0.1, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, bfoa_custom, bfoa_customc, max_evals=1000)

    def test_griewank_ngen(self):
        bfoa_custom = self.algo(population_size=10, n_chemotactic=100, n_reproduction=4, n_elimination=1, step_size=0.1,
                                seed=self.seed)
        bfoa_customc = self.algo(population_size=10, n_chemotactic=100, n_reproduction=4, n_elimination=1,
                                 step_size=0.1, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, bfoa_custom, bfoa_customc, max_iters=1000)

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



# encoding=utf8

from niapy.algorithms.basic import CoralReefsOptimization
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class CROTestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = CoralReefsOptimization

    def test_custom(self):
        cro_custom = self.algo(population_size=10, seed=self.seed)
        cro_customc = self.algo(population_size=10, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, cro_custom, cro_customc, MyProblem(), max_iters=100)

    def test_griewank(self):
        cro_griewank = self.algo(population_size=10, seed=self.seed)
        cro_griewankc = self.algo(population_size=10, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, cro_griewank, cro_griewankc, max_iters=100)

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



# encoding=utf8
from niapy.algorithms.basic import MothFlameOptimizer
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class MFOTestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = MothFlameOptimizer

    def test_custom(self):
        mfo_custom = self.algo(population_size=10, seed=self.seed)
        mfo_customc = self.algo(population_size=10, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, mfo_custom, mfo_customc, MyProblem())

    def test_griewank(self):
        mfo_griewank = self.algo(population_size=10, seed=self.seed)
        mfo_griewankc = self.algo(population_size=10, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, mfo_griewank, mfo_griewankc)

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



# encoding=utf8
import logging
from unittest import TestCase

import numpy as np

from niapy.problems import Problem

logging.basicConfig()
logger = logging.getLogger('niapy.test')
logger.setLevel('INFO')


class Dummy(Problem):
    def _evaluate(self, x):
        return np.inf


class ProblemTestCase(TestCase):
    def setUp(self):
        self.Lower, self.Upper = np.array([-19, -10]), np.array([19, 5])
        self.bc = Dummy
        self.b = self.bc(2, self.Lower, self.Upper)

    def test_lower(self):
        self.assertTrue(np.array_equal(self.Lower, self.b.lower))

    def test_upper(self):
        self.assertTrue(np.array_equal(self.Upper, self.b.upper))

    def test_function_eval(self):
        self.assertEqual(np.inf, self.b.evaluate(self.Upper))

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



# encoding=utf8

from niapy.algorithms.basic import GlowwormSwarmOptimization, GlowwormSwarmOptimizationV1, GlowwormSwarmOptimizationV2, \
    GlowwormSwarmOptimizationV3
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class GSOTestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = GlowwormSwarmOptimization

    def test_custom(self):
        gso_custom = self.algo(population_size=10, a=7, Rmin=0.1, Rmax=3, seed=self.seed)
        gso_customc = self.algo(population_size=10, a=7, Rmin=0.1, Rmax=3, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, gso_custom, gso_customc, MyProblem())

    def test_griewank(self):
        gso_griewank = self.algo(population_size=10, a=5, Rmin=0.01, Rmax=3, seed=self.seed)
        gso_griewankc = self.algo(population_size=10, a=5, Rmin=0.01, Rmax=3, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, gso_griewank, gso_griewankc)


class GSOv1TestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = GlowwormSwarmOptimizationV1

    def test_custom(self):
        gso_custom = self.algo(population_size=10, seed=self.seed)
        gso_customc = self.algo(population_size=10, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, gso_custom, gso_customc, MyProblem())

    def test_griewank(self):
        gso_griewank = self.algo(population_size=10, seed=self.seed)
        gso_griewankc = self.algo(population_size=10, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, gso_griewank, gso_griewankc)


class GSOv2TestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = GlowwormSwarmOptimizationV2

    def test_custom(self):
        gso_custom = self.algo(population_size=10, a=7, Rmin=0.1, Rmax=3, seed=self.seed)
        gso_customc = self.algo(population_size=10, a=7, Rmin=0.1, Rmax=3, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, gso_custom, gso_customc, MyProblem())

    def test_griewank(self):
        gso_griewank = self.algo(population_size=10, a=5, Rmin=0.01, Rmax=3, seed=self.seed)
        gso_griewankc = self.algo(population_size=10, a=5, Rmin=0.01, Rmax=3, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, gso_griewank, gso_griewankc)


class GSOv3TestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = GlowwormSwarmOptimizationV3

    def test_custom(self):
        gso_custom = self.algo(population_size=10, a=7, Rmin=0.1, Rmax=3, seed=self.seed)
        gso_customc = self.algo(population_size=10, a=7, Rmin=0.1, Rmax=3, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, gso_custom, gso_customc, MyProblem())

    def test_griewank(self):
        gso_griewank = self.algo(population_size=10, a=5, Rmin=0.01, Rmax=3, seed=self.seed)
        gso_griewankc = self.algo(population_size=10, a=5, Rmin=0.01, Rmax=3, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, gso_griewank, gso_griewankc)

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



# encoding=utf8

from niapy.algorithms.other import SimulatedAnnealing
from niapy.algorithms.other.sa import cool_linear
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class SATestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = SimulatedAnnealing

    def test_custom(self):
        ca_custom = self.algo(population_size=10, seed=self.seed)
        ca_customc = self.algo(population_size=10, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ca_custom, ca_customc, MyProblem())

    def test_griewank(self):
        ca_griewank = self.algo(population_size=10, seed=self.seed)
        ca_griewankc = self.algo(population_size=10, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ca_griewank, ca_griewankc)

    def test_custom1(self):
        ca_custom = self.algo(population_size=10, seed=self.seed, cooling_method=cool_linear)
        ca_customc = self.algo(population_size=10, seed=self.seed, cooling_method=cool_linear)
        AlgorithmTestCase.test_algorithm_run(self, ca_custom, ca_customc, MyProblem())

    def test_griewank1(self):
        ca_griewank = self.algo(population_size=10, seed=self.seed, cooling_method=cool_linear)
        ca_griewankc = self.algo(population_size=10, seed=self.seed, cooling_method=cool_linear)
        AlgorithmTestCase.test_algorithm_run(self, ca_griewank, ca_griewankc)

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



# encoding=utf8

from niapy.algorithms.basic import BatAlgorithm
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class BATestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = BatAlgorithm

    def test_custom(self):
        ba_custom = self.algo(population_size=10, loudness=0.5, pulse_rate=0.5, min_frequency=0.0, max_frequency=2.0, seed=self.seed)
        ba_customc = self.algo(population_size=10, loudness=0.5, pulse_rate=0.5, min_frequency=0.0, max_frequency=2.0, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ba_custom, ba_customc, MyProblem())

    def test_griewank(self):
        ba_griewank = self.algo(population_size=10, loudness=0.5, pulse_rate=0.5, min_frequency=0.0, max_frequency=2.0, seed=self.seed)
        ba_griewankc = self.algo(population_size=10, loudness=0.5, pulse_rate=0.5, min_frequency=0.0, max_frequency=2.0, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ba_griewank, ba_griewankc)

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



# encoding=utf8
from niapy.algorithms.other import HillClimbAlgorithm
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class HCTestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = HillClimbAlgorithm

    def test_custom(self):
        ihc_custom = self.algo(delta=0.4, seed=self.seed)
        ihc_customc = self.algo(delta=0.4, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ihc_custom, ihc_customc, MyProblem())

    def test_griewank(self):
        ihc_griewank = self.algo(delta=0.1, seed=self.seed)
        ihc_griewankc = self.algo(delta=0.1, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ihc_griewank, ihc_griewankc)

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



# encoding=utf8
from niapy.algorithms.modified import HybridBatAlgorithm
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class HBATestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = HybridBatAlgorithm

    def test_custom(self):
        hba_custom = self.algo(population_size=10, loudness=0.5, pulse_rate=0.5, differential_weight=0.5,
                               crossover_probability=0.9, min_frequency=0.0, max_frequency=2.0, seed=self.seed)
        hba_customc = self.algo(population_size=10, loudness=0.5, pulse_rate=0.5, differential_weight=0.5,
                                crossover_probability=0.9, min_frequency=0.0, max_frequency=2.0, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, hba_custom, hba_customc, MyProblem())

    def test_griewank(self):
        hba_griewank = self.algo(population_size=10, loudness=0.5, pulse_rate=0.5, differential_weight=0.5,
                                 crossover_probability=0.9, min_frequency=0.0, max_frequency=2.0, seed=self.seed)
        hba_griewankc = self.algo(population_size=10, loudness=0.5, pulse_rate=0.5, differential_weight=0.5,
                                  crossover_probability=0.9, min_frequency=0.0, max_frequency=2.0, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, hba_griewank, hba_griewankc)

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



# encoding=utf8

from niapy.algorithms.other import RandomSearch
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class RSTestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = RandomSearch

    def test_custom(self):
        ca_custom = self.algo(population_size=10, seed=self.seed)
        ca_customc = self.algo(population_size=10, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ca_custom, ca_customc, MyProblem(), max_iters=100, max_evals=50000)

    def test_griewank(self):
        ca_griewank = self.algo(population_size=10, seed=self.seed)
        ca_griewankc = self.algo(population_size=10, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ca_griewank, ca_griewankc, max_iters=100, max_evals=50000)



# encoding=utf8
from unittest import TestCase

import numpy as np
import niapy
from niapy.problems import Problem


class MyProblem(Problem):
    def __init__(self, dimension):
        super().__init__(dimension, -11, 11)

    def _evaluate(self, x):
        return np.sum(x ** 2)


class RunnerTestCase(TestCase):
    def setUp(self):
        self.algorithms = ['DifferentialEvolution', 'GreyWolfOptimizer', 'GeneticAlgorithm']
        self.problems = ['griewank', MyProblem(7)]

    def test_runner(self):
        self.assertTrue(niapy.Runner(7, 100, 2, self.algorithms, self.problems).run())

    def test_runner_bad_algorithm_throws(self):
        self.assertRaises(KeyError, lambda: niapy.Runner(4, 10, 3, ['EvolutionStrategy'], self.problems).run())

    def test_runner_bad_problem_throws(self):
        self.assertRaises(KeyError, lambda: niapy.Runner(4, 10, 3, ['EvolutionStrategy1p1'], ['TesterMan']).run())

    def test_runner_bad_export_throws(self):
        self.assertRaises(TypeError,
                          lambda: niapy.Runner(4, 10, 3, ['GreyWolfOptimizer'], self.problems).run(export="pandas"))

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



# encoding=utf8
from unittest import TestCase

from niapy.algorithms.basic import EvolutionStrategy1p1, EvolutionStrategyMp1, EvolutionStrategyMpL, EvolutionStrategyML
from niapy.algorithms.basic.es import IndividualES
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class IndividualESTestCase(TestCase):
    def test_init_ok_one(self):
        i = IndividualES()
        self.assertEqual(i.rho, 1.0)

    def test_init_ok_two(self):
        i = IndividualES(rho=10)
        self.assertEqual(i.rho, 10)


class ES1p1TestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = EvolutionStrategy1p1

    def test_custom(self):
        es_custom = self.algo(k=10, c_a=1.5, c_r=0.42, seed=self.seed)
        es_customc = self.algo(k=10, c_a=1.5, c_r=0.42, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, es_custom, es_customc, MyProblem())

    def test_griewank(self):
        es_griewank = self.algo(k=15, c_a=1.2, c_r=0.5, seed=self.seed)
        es_griewankc = self.algo(k=15, c_a=1.2, c_r=0.5, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, es_griewank, es_griewankc)


class ESMp1TestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = EvolutionStrategyMp1

    def test_custom(self):
        es_custom = self.algo(mu=10, k=50, c_a=1.1, c_r=0.5, seed=self.seed)
        es_customc = self.algo(mu=10, k=50, c_a=1.1, c_r=0.5, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, es_custom, es_customc, MyProblem())

    def test_griewank(self):
        es_griewank = self.algo(mu=10, k=25, c_a=1.5, c_r=0.5, seed=self.seed)
        es_griewankc = self.algo(mu=10, k=25, c_a=1.5, c_r=0.5, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, es_griewank, es_griewankc)


class ESMpLTestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = EvolutionStrategyMpL

    def test_custom(self):
        es_custom = self.algo(mu=10, lam=55, k=50, c_a=1.1, c_r=0.5, seed=self.seed)
        es_customc = self.algo(mu=10, lam=55, k=50, c_a=1.1, c_r=0.5, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, es_custom, es_customc, MyProblem())

    def test_griewank(self):
        es_griewank = self.algo(mu=10, lam=50, k=25, c_a=1.5, c_r=0.5, seed=self.seed)
        es_griewankc = self.algo(mu=10, lam=50, k=25, c_a=1.5, c_r=0.5, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, es_griewank, es_griewankc)

    def test_custom1(self):
        es1_custom = self.algo(mu=10, lam=45, k=50, c_a=1.1, c_r=0.5, seed=self.seed)
        es1_customc = self.algo(mu=10, lam=45, k=50, c_a=1.1, c_r=0.5, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, es1_custom, es1_customc, MyProblem())

    def test_griewank1(self):
        es1_griewank = self.algo(mu=10, lam=30, k=25, c_a=1.5, c_r=0.5, seed=self.seed)
        es1_griewankc = self.algo(mu=10, lam=30, k=25, c_a=1.5, c_r=0.5, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, es1_griewank, es1_griewankc)


class ESMLTestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = EvolutionStrategyML

    def test_custom(self):
        es_custom = self.algo(mu=10, k=50, c_a=1.1, c_r=0.5, seed=self.seed)
        es_customc = self.algo(mu=10, k=50, c_a=1.1, c_r=0.5, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, es_custom, es_customc, MyProblem())

    def test_griewank(self):
        es_griewank = self.algo(mu=10, lam=45, k=45, c_a=1.5, c_r=0.5, seed=self.seed)
        es_griewankc = self.algo(mu=10, lam=45, k=45, c_a=1.5, c_r=0.5, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, es_griewank, es_griewankc)

    def test_custom1(self):
        es1_custom = self.algo(mu=10, lam=35, k=50, c_a=1.1, c_r=0.5, seed=self.seed)
        es1_customc = self.algo(mu=10, lam=35, k=50, c_a=1.1, c_r=0.5, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, es1_custom, es1_customc, MyProblem())

    def test_griewank1(self):
        es1_griewank = self.algo(mu=10, lam=35, k=25, c_a=1.5, c_r=0.5, seed=self.seed)
        es1_griewankc = self.algo(mu=10, lam=35, k=25, c_a=1.5, c_r=0.5, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, es1_griewank, es1_griewankc)

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



# encoding=utf8
from niapy.algorithms.basic import FishSchoolSearch
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class FSSTestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = FishSchoolSearch

    def test_custom(self):
        fss_custom = self.algo(population_size=10, seed=self.seed)
        fss_customc = self.algo(population_size=10, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, fss_custom, fss_customc, MyProblem())

    def test_griewank(self):
        fss_custom = self.algo(population_size=10, seed=self.seed)
        fss_customc = self.algo(population_size=10, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, fss_custom, fss_customc)

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



# encoding=utf8
from unittest import TestCase

from numpy.random import default_rng

from niapy.algorithms.modified import SelfAdaptiveDifferentialEvolution, \
    MultiStrategySelfAdaptiveDifferentialEvolution
from niapy.algorithms.modified.jde import SolutionJDE
from niapy.task import Task
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class SolutionJDETestCase(TestCase):
    def setUp(self):
        self.D, self.F, self.CR = 10, 0.9, 0.3
        self.x, self.task = default_rng().uniform(10, 50, self.D), Task(problem=MyProblem(self.D))
        self.s1, self.s2 = SolutionJDE(task=self.task, e=False), SolutionJDE(differential_weight=self.F,
                                                                             crossover_probability=self.CR, x=self.x)

    def test_F(self):
        self.assertAlmostEqual(self.s1.differential_weight, 2)
        self.assertAlmostEqual(self.s2.differential_weight, self.F)

    def test_cr(self):
        self.assertAlmostEqual(self.s1.crossover_probability, 0.5)
        self.assertAlmostEqual(self.s2.crossover_probability, self.CR)


class JDETestCase(AlgorithmTestCase):

    def test_custom(self):
        jde_custom = SelfAdaptiveDifferentialEvolution(f_lower=0.0, f_upper=2.0, tao1=0.9, tao2=0.45,
                                                       population_size=10, differential_weight=0.5,
                                                       crossover_probability=0.1, seed=self.seed)
        jde_customc = SelfAdaptiveDifferentialEvolution(f_lower=0.0, f_upper=2.0, tao1=0.9, tao2=0.45,
                                                        population_size=10, differential_weight=0.5,
                                                        crossover_probability=0.1, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, jde_custom, jde_customc, MyProblem())

    def test_griewank(self):
        jde_griewank = SelfAdaptiveDifferentialEvolution(f_lower=0.0, f_upper=2.0, tao1=0.9, tao2=0.45,
                                                         population_size=10, differential_weight=0.5,
                                                         crossover_probability=0.1, seed=self.seed)
        jde_griewankc = SelfAdaptiveDifferentialEvolution(f_lower=0.0, f_upper=2.0, tao1=0.9, tao2=0.45,
                                                          population_size=10, differential_weight=0.5,
                                                          crossover_probability=0.1, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, jde_griewank, jde_griewankc)


class MsjDETestCase(AlgorithmTestCase):
    def test_custom(self):
        jde_custom = MultiStrategySelfAdaptiveDifferentialEvolution(population_size=10, differential_weight=0.5,
                                                                    f_lower=0.0, f_upper=2.0, tao1=0.9,
                                                                    crossover_probability=0.1,
                                                                    tao2=0.45, seed=self.seed)
        jde_customc = MultiStrategySelfAdaptiveDifferentialEvolution(population_size=10, differential_weight=0.5,
                                                                     f_lower=0.0, f_upper=2.0, tao1=0.9,
                                                                     crossover_probability=0.1,
                                                                     tao2=0.45, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, jde_custom, jde_customc, MyProblem())

    def test_griewank(self):
        jde_griewank = MultiStrategySelfAdaptiveDifferentialEvolution(population_size=10, differential_weight=0.5,
                                                                      f_lower=0.0, f_upper=2.0, tao1=0.9,
                                                                      crossover_probability=0.1,
                                                                      tao2=0.45, seed=self.seed)
        jde_griewankc = MultiStrategySelfAdaptiveDifferentialEvolution(population_size=10, differential_weight=0.5,
                                                                       f_lower=0.0, f_upper=2.0, tao1=0.9,
                                                                       crossover_probability=0.1,
                                                                       tao2=0.45, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, jde_griewank, jde_griewankc)

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



# encoding=utf8
from unittest import TestCase

import numpy as np
from numpy.random import default_rng

from niapy.util import full_array, repair


class FullArrayTestCase(TestCase):
    def test_a_float(self):
        arr = full_array(25.25, 10)
        self.assertTrue(np.array_equal(arr, np.full(10, 25.25)))

    def test_a_int(self):
        arr = full_array(25, 10)
        self.assertTrue(np.array_equal(arr, np.full(10, 25)))

    def test_a_float_list(self):
        a = [25.25] * 10
        arr = full_array(a, 10)
        self.assertTrue(np.array_equal(arr, np.full(10, 25.25)))

    def test_a_int_list(self):
        a = [25] * 10
        arr = full_array(a, 10)
        self.assertTrue(np.array_equal(arr, np.full(10, 25)))

    def test_a_float_array(self):
        a = np.asarray([25.25] * 10)
        arr = full_array(a, 10)
        self.assertTrue(np.array_equal(arr, np.full(10, 25.25)))

    def test_a_int_array(self):
        a = np.asarray([25] * 10)
        arr = full_array(a, 10)
        self.assertTrue(np.array_equal(arr, np.full(10, 25)))

    def test_a_float_list1(self):
        a = [25.25 + i for i in range(10)]
        arr = full_array(a, 15)
        a.extend([25.25 + i for i in range(5)])
        self.assertTrue(np.array_equal(arr, np.asarray(a)))

    def test_a_int_list1(self):
        a = [25 + i for i in range(10)]
        arr = full_array(a, 15)
        a.extend([25 + i for i in range(5)])
        self.assertTrue(np.array_equal(arr, np.asarray(a)))

    def test_a_float_array1(self):
        a = [25.25 + i for i in range(10)]
        arr = full_array(np.asarray(a), 15)
        a.extend([25.25 + i for i in range(5)])
        self.assertTrue(np.array_equal(arr, np.asarray(a)))

    def test_a_int_array1(self):
        a = [25 + i for i in range(10)]
        arr = full_array(np.asarray(a), 15)
        a.extend([25 + i for i in range(5)])
        self.assertTrue(np.array_equal(arr, np.asarray(a)))

    def test_a_float_list2(self):
        a = [25.25 + i for i in range(10)]
        arr = full_array(a, 13)
        a.extend([25.25 + i for i in range(3)])
        self.assertTrue(np.array_equal(arr, np.asarray(a)))

    def test_a_int_list2(self):
        a = [25 + i for i in range(10)]
        arr = full_array(a, 13)
        a.extend([25 + i for i in range(3)])
        self.assertTrue(np.array_equal(arr, np.asarray(a)))

    def test_a_float_array2(self):
        a = [25.25 + i for i in range(10)]
        arr = full_array(np.asarray(a), 13)
        a.extend([25.25 + i for i in range(3)])
        self.assertTrue(np.array_equal(arr, np.asarray(a)))

    def test_a_int_array2(self):
        a = [25 + i for i in range(10)]
        arr = full_array(np.asarray(a), 13)
        a.extend([25 + i for i in range(3)])
        self.assertTrue(np.array_equal(arr, np.asarray(a)))

    def test_a_float_list3(self):
        a = [25.25 + i for i in range(10)]
        arr = full_array(a, 9)
        a.remove(34.25)
        self.assertTrue(np.array_equal(arr, np.asarray(a)))

    def test_a_int_list3(self):
        a = [25 + i for i in range(10)]
        arr = full_array(a, 9)
        a.remove(34)
        self.assertTrue(np.array_equal(arr, np.asarray(a)))

    def test_a_float_array3(self):
        a = [25.25 + i for i in range(10)]
        arr = full_array(np.asarray(a), 9)
        a.remove(34.25)
        self.assertTrue(np.array_equal(arr, np.asarray(a)))

    def test_a_int_array3(self):
        a = [25 + i for i in range(10)]
        arr = full_array(np.asarray(a), 9)
        a.remove(34)
        self.assertTrue(np.array_equal(arr, np.asarray(a)))


def generate_individual(dim, upper, lower):
    upp, low = full_array(upper, dim), full_array(lower, dim)
    return default_rng().uniform(low, upp, dim)


class LimitRepairTestCase(TestCase):
    def setUp(self):
        self.D = 10
        self.Upper, self.Lower = full_array(10, self.D), full_array(-10, self.D)
        self.met = repair.limit

    def test_limit_repair_good_solution(self):
        x = generate_individual(self.D, self.Upper, self.Lower)
        x = self.met(x, self.Lower, self.Upper)
        self.assertFalse((x > self.Upper).any())
        self.assertFalse((x < self.Lower).any())

    def test_limit_repair_bad_upper_solution(self):
        x = generate_individual(self.D, 12, 11)
        x = self.met(x, self.Lower, self.Upper)
        self.assertFalse((x > self.Upper).any())
        self.assertFalse((x < self.Lower).any())

    def test_limit_repair_bad_lower_solution(self):
        x = generate_individual(self.D, -11, -12)
        x = self.met(x, self.Lower, self.Upper)
        self.assertFalse((x > self.Upper).any())
        self.assertFalse((x < self.Lower).any())

    def test_limit_repair_bad_upper_lower_solution(self):
        x = generate_individual(self.D, 100, -100)
        x = self.met(x, self.Lower, self.Upper)
        self.assertFalse((x > self.Upper).any())
        self.assertFalse((x < self.Lower).any())


class LimitInverseRepairTestCase(LimitRepairTestCase):
    def setUp(self):
        LimitRepairTestCase.setUp(self)
        self.met = repair.limit_inverse


class WangRepairTestCase(LimitRepairTestCase):
    def setUp(self):
        LimitRepairTestCase.setUp(self)
        self.met = repair.wang


class RandRepairTestCase(LimitRepairTestCase):
    def setUp(self):
        LimitRepairTestCase.setUp(self)
        self.met = repair.rand


class ReflectRepairTestCase(LimitRepairTestCase):
    def setUp(self):
        LimitRepairTestCase.setUp(self)
        self.met = repair.reflect

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



# encoding=utf8
from niapy.algorithms.modified import DifferentialEvolutionMTS, DifferentialEvolutionMTSv1, \
    MultiStrategyDifferentialEvolutionMTS, MultiStrategyDifferentialEvolutionMTSv1, \
    DynNpMultiStrategyDifferentialEvolutionMTS, DynNpMultiStrategyDifferentialEvolutionMTSv1, \
    DynNpDifferentialEvolutionMTS, DynNpDifferentialEvolutionMTSv1
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class DEMTSTestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = DifferentialEvolutionMTS

    def test_custom(self):
        ca_custom = self.algo(population_size=10, num_tests=1, num_searches=2, num_enabled=2, seed=self.seed)
        ca_customc = self.algo(population_size=10, num_tests=1, num_searches=2, num_enabled=2, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ca_custom, ca_customc, MyProblem(), max_iters=100)

    def test_griewank(self):
        ca_griewank = self.algo(population_size=10, num_tests=1, num_searches=2, num_enabled=2, seed=self.seed)
        ca_griewankc = self.algo(population_size=10, num_tests=1, num_searches=2, num_enabled=2, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ca_griewank, ca_griewankc, max_iters=100)


class DEMTSv1TestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = DifferentialEvolutionMTSv1

    def test_custom(self):
        ca_custom = self.algo(population_size=10, num_tests=1, num_searches=2, num_enabled=2, seed=self.seed)
        ca_customc = self.algo(population_size=10, num_tests=1, num_searches=2, num_enabled=2, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ca_custom, ca_customc, MyProblem(), max_iters=100)

    def test_griewank(self):
        ca_griewank = self.algo(population_size=10, num_tests=1, num_searches=2, num_enabled=2, seed=self.seed)
        ca_griewankc = self.algo(population_size=10, num_tests=1, num_searches=2, num_enabled=2, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ca_griewank, ca_griewankc, max_iters=100)


class DynNpDEMTSTestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = DynNpDifferentialEvolutionMTS

    def test_custom(self):
        ca_custom = self.algo(population_size=10, num_tests=1, num_searches=2, num_enabled=2, p_max=10, rp=3, seed=self.seed)
        ca_customc = self.algo(population_size=10, num_tests=1, num_searches=2, num_enabled=2, p_max=10, rp=3, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ca_custom, ca_customc, MyProblem())

    def test_griewank(self):
        ca_griewank = self.algo(population_size=10, num_tests=1, num_searches=2, num_enabled=2, p_max=10, rp=3, seed=self.seed)
        ca_griewankc = self.algo(population_size=10, num_tests=1, num_searches=2, num_enabled=2, p_max=10, rp=3, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ca_griewank, ca_griewankc, max_iters=100)


class DynNpDEMTSv1TestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = DynNpDifferentialEvolutionMTSv1

    def test_custom(self):
        ca_custom = self.algo(population_size=10, num_tests=1, num_searches=2, num_enabled=2, p_max=10, rp=3, seed=self.seed)
        ca_customc = self.algo(population_size=10, num_tests=1, num_searches=2, num_enabled=2, p_max=10, rp=3, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ca_custom, ca_customc, MyProblem(), max_iters=100)

    def test_griewank(self):
        ca_griewank = self.algo(population_size=10, num_tests=1, num_searches=2, num_enabled=2, p_max=10, rp=3, seed=self.seed)
        ca_griewankc = self.algo(population_size=10, num_tests=1, num_searches=2, num_enabled=2, p_max=10, rp=3, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ca_griewank, ca_griewankc, max_iters=100)


class MSDEMTSTestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = MultiStrategyDifferentialEvolutionMTS

    def test_custom(self):
        ca_custom = self.algo(population_size=10, num_tests=1, num_searches=2, num_enabled=2, seed=self.seed)
        ca_customc = self.algo(population_size=10, num_tests=1, num_searches=2, num_enabled=2, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ca_custom, ca_customc, MyProblem())

    def test_griewank(self):
        ca_griewank = self.algo(population_size=10, num_tests=1, num_searches=2, num_enabled=2, seed=self.seed)
        ca_griewankc = self.algo(population_size=10, num_tests=1, num_searches=2, num_enabled=2, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ca_griewank, ca_griewankc, max_iters=100)


class MSDEMTSv1STestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = MultiStrategyDifferentialEvolutionMTSv1

    def test_custom(self):
        ca_custom = self.algo(population_size=10, num_tests=1, num_searches=2, num_enabled=2, seed=self.seed)
        ca_customc = self.algo(population_size=10, num_tests=1, num_searches=2, num_enabled=2, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ca_custom, ca_customc, MyProblem(), max_iters=100)

    def test_griewank(self):
        ca_griewank = self.algo(population_size=10, num_tests=1, num_searches=2, num_enabled=2, seed=self.seed)
        ca_griewankc = self.algo(population_size=10, num_tests=1, num_searches=2, num_enabled=2, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ca_griewank, ca_griewankc, max_iters=100)


class DynNpMSDEMTSTestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = DynNpMultiStrategyDifferentialEvolutionMTS

    def test_custom(self):
        ca_custom = self.algo(population_size=10, num_tests=1, num_searches=2, num_enabled=2, seed=self.seed)
        ca_customc = self.algo(population_size=10, num_tests=1, num_searches=2, num_enabled=2, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ca_custom, ca_customc, MyProblem(), max_iters=100)

    def test_griewank(self):
        ca_griewank = self.algo(population_size=10, num_tests=1, num_searches=2, num_enabled=2, seed=self.seed)
        ca_griewankc = self.algo(population_size=10, num_tests=1, num_searches=2, num_enabled=2, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ca_griewank, ca_griewankc, max_iters=100)


class DynNpMSDEMTSv1TestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = DynNpMultiStrategyDifferentialEvolutionMTSv1

    def test_custom(self):
        ca_custom = self.algo(population_size=10, num_tests=1, num_searches=2, num_enabled=2, seed=self.seed)
        ca_customc = self.algo(population_size=10, num_tests=1, num_searches=2, num_enabled=2, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ca_custom, ca_customc, MyProblem(), max_iters=100)

    def test_griewank(self):
        ca_griewank = self.algo(population_size=10, num_tests=1, num_searches=2, num_enabled=2, seed=self.seed)
        ca_griewankc = self.algo(population_size=10, num_tests=1, num_searches=2, num_enabled=2, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ca_griewank, ca_griewankc, max_iters=100)

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



# encoding=utf8

from niapy.algorithms.basic import BareBonesFireworksAlgorithm, FireworksAlgorithm, EnhancedFireworksAlgorithm, \
    DynamicFireworksAlgorithm, DynamicFireworksAlgorithmGauss
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class BBFWATestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = BareBonesFireworksAlgorithm

    def test_custom(self):
        bbfwa_custom = self.algo(num_sparks=10, amplification_coefficient=2, reduction_coefficient=0.5, seed=self.seed)
        bbfwa_customc = self.algo(num_sparks=10, amplification_coefficient=2, reduction_coefficient=0.5, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, bbfwa_custom, bbfwa_customc, MyProblem())

    def test_griewank(self):
        bbfwa_griewank = self.algo(num_sparks=10, amplification_coefficient=5, reduction_coefficient=0.5, seed=self.seed)
        bbfwa_griewankc = self.algo(num_sparks=10, amplification_coefficient=5, reduction_coefficient=0.5, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, bbfwa_griewank, bbfwa_griewankc)


class FWATestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = FireworksAlgorithm

    def test_custom(self):
        fwa_custom = self.algo(population_size=10, seed=self.seed)
        fwa_customc = self.algo(population_size=10, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, fwa_custom, fwa_customc, MyProblem())

    def test_griewank(self):
        fwa_griewank = self.algo(population_size=10, seed=self.seed)
        fwa_griewankc = self.algo(population_size=10, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, fwa_griewank, fwa_griewankc)


class EFWATestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = EnhancedFireworksAlgorithm

    def test_custom(self):
        fwa_custom = self.algo(population_size=10, seed=self.seed)
        fwa_customc = self.algo(population_size=10, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, fwa_custom, fwa_customc, MyProblem(), max_evals=12345, max_iters=17)

    def test_griewank(self):
        fwa_griewank = self.algo(population_size=10, seed=self.seed)
        fwa_griewankc = self.algo(population_size=10, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, fwa_griewank, fwa_griewankc)


class DFWATestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = DynamicFireworksAlgorithm

    def test_custom(self):
        fwa_custom = self.algo(population_size=10, C_a=2, C_r=0.5, seed=self.seed)
        fwa_customc = self.algo(population_size=10, C_a=2, C_r=0.5, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, fwa_custom, fwa_customc, MyProblem())

    def test_griewank(self):
        fwa_griewank = self.algo(population_size=10, C_a=5, C_r=0.5, seed=self.seed)
        fwa_griewankc = self.algo(population_size=10, C_a=5, C_r=0.5, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, fwa_griewank, fwa_griewankc)


class DFWAGTestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = DynamicFireworksAlgorithmGauss

    def test_custom(self):
        fwa_custom = self.algo(population_size=10, C_a=2, C_r=0.5, seed=self.seed)
        fwa_customc = self.algo(population_size=10, C_a=2, C_r=0.5, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, fwa_custom, fwa_customc, MyProblem())

    def test_griewank(self):
        fwa_griewank = self.algo(population_size=10, C_a=5, C_r=0.5, seed=self.seed)
        fwa_griewankc = self.algo(population_size=10, C_a=5, C_r=0.5, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, fwa_griewank, fwa_griewankc)

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



from niapy.algorithms.basic import MonarchButterflyOptimization
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class MBOTestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = MonarchButterflyOptimization

    def test(self):
        mbo = self.algo(population_size=10, PAR=5.0 / 12.0, PER=1.2, seed=self.seed)
        mboc = self.algo(population_size=10, PAR=5.0 / 12.0, PER=1.2, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, mbo, mboc, MyProblem())

    def test_griewank(self):
        mbo_griewank = self.algo(population_size=10, PAR=5.0 / 12.0, PER=1.2, seed=self.seed)
        mbo_griewankc = self.algo(population_size=10, PAR=5.0 / 12.0, PER=1.2, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, mbo_griewank, mbo_griewankc)



# encoding=utf8
from niapy.algorithms.basic import ClonalSelectionAlgorithm
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class ClonalgTestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = ClonalSelectionAlgorithm

    def test_custom(self):
        clonalg_custom = self.algo(population_size=10, seed=self.seed)
        clonalg_customc = self.algo(population_size=10, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, clonalg_custom, clonalg_customc, MyProblem())

    def test_griewank(self):
        clonalg_griewank = self.algo(population_size=10, seed=self.seed)
        clonalg_griewankc = self.algo(population_size=10, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, clonalg_griewank, clonalg_griewankc)



# encoding=utf8
from niapy.algorithms.other import NelderMeadMethod
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class NMMTestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = NelderMeadMethod

    def test_custom(self):
        nmm_custom = self.algo(population_size=10, C_a=2, C_r=0.5, seed=self.seed)
        nmm_customc = self.algo(population_size=10, C_a=2, C_r=0.5, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, nmm_custom, nmm_customc, MyProblem())

    def test_griewank(self):
        nmm_griewank = self.algo(population_size=10, C_a=5, C_r=0.5, seed=self.seed)
        nmm_griewankc = self.algo(population_size=10, C_a=5, C_r=0.5, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, nmm_griewank, nmm_griewankc)

    def test_michalewichz(self):
        nmm_griewank = self.algo(population_size=10, C_a=5, C_r=0.5, seed=self.seed)
        nmm_griewankc = self.algo(population_size=10, C_a=5, C_r=0.5, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, nmm_griewank, nmm_griewankc, 'michalewicz', max_iters=10000000)

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



# encoding=utf8

from niapy.algorithms.basic import CatSwarmOptimization
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class CSOTestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = CatSwarmOptimization

    def test_custom(self):
        cso_custom = self.algo(population_size=10, seed=self.seed)
        cso_customc = self.algo(population_size=10, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, cso_custom, cso_customc, MyProblem())

    def test_griewank(self):
        cso_griewank = self.algo(population_size=10, seed=self.seed)
        cso_griewankc = self.algo(population_size=10, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, cso_griewank, cso_griewankc)



# encoding=utf8

"""Implementations of Step functions."""

import numpy as np
from niapy.problems.problem import Problem

__all__ = ['Step', 'Step2', 'Step3']


class Step(Problem):
    r"""Implementation of Step function.

    Date: 2018

    Author: Lucija Brezočnik

    License: MIT

    Function: **Step function**

        :math:`f(\mathbf{x}) = \sum_{i=1}^D \left( \lfloor \left |
        x_i \right | \rfloor \right)`

        **Input domain:**
        The function can be defined on any input domain but it is usually
        evaluated on the hypercube :math:`x_i ∈ [-100, 100]`, for all :math:`i = 1, 2,..., D`.

        **Global minimum:** :math:`f(x^*) = 0`, at :math:`x^* = (0,...,0)`

    LaTeX formats:
        Inline:
            $f(\mathbf{x}) = \sum_{i=1}^D \left( \lfloor \left |
            x_i \right | \rfloor \right)$

        Equation:
            \begin{equation} f(\mathbf{x}) = \sum_{i=1}^D \left(
            \lfloor \left | x_i \right | \rfloor \right) \end{equation}

        Domain:
            $-100 \leq x_i \leq 100$

    Reference paper:
        Jamil, M., and Yang, X. S. (2013).
        A literature survey of benchmark functions for global optimisation problems.
        International Journal of Mathematical Modelling and Numerical Optimisation,
        4(2), 150-194.

    """

    def __init__(self, dimension=4, lower=-100.0, upper=100.0, *args, **kwargs):
        r"""Initialize Step problem..

        Args:
            dimension (Optional[int]): Dimension of the problem.
            lower (Optional[Union[float, Iterable[float]]]): Lower bounds of the problem.
            upper (Optional[Union[float, Iterable[float]]]): Upper bounds of the problem.

        See Also:
            :func:`niapy.problems.Problem.__init__`

        """
        super().__init__(dimension, lower, upper, *args, **kwargs)

    @staticmethod
    def latex_code():
        r"""Return the latex code of the problem.

        Returns:
            str: Latex code.

        """
        return r'''$f(\mathbf{x}) = \sum_{i=1}^D \left( \lfloor \left | x_i \right | \rfloor \right)$'''

    def _evaluate(self, x):
        return np.sum(np.floor(np.abs(x)))


class Step2(Problem):
    r"""Step2 function implementation.

    Date: 2018

    Author: Lucija Brezočnik

    Licence: MIT

    Function: **Step2 function**

        :math:`f(\mathbf{x}) = \sum_{i=1}^D \left( \lfloor x_i + 0.5 \rfloor \right)^2`

        **Input domain:**
        The function can be defined on any input domain but it is usually
        evaluated on the hypercube :math:`x_i ∈ [-100, 100]`, for all :math:`i = 1, 2,..., D`.

        **Global minimum:** :math:`f(x^*) = 0`, at :math:`x^* = (-0.5,...,-0.5)`

    LaTeX formats:
        Inline:
            $f(\mathbf{x}) = \sum_{i=1}^D \left( \lfloor x_i + 0.5 \rfloor \right)^2$

        Equation:
            \begin{equation}f(\mathbf{x}) = \sum_{i=1}^D \left(
            \lfloor x_i + 0.5 \rfloor \right)^2 \end{equation}

        Domain:
            $-100 \leq x_i \leq 100$

    Reference paper:
        Jamil, M., and Yang, X. S. (2013).
        A literature survey of benchmark functions for global optimisation problems.
        International Journal of Mathematical Modelling and Numerical Optimisation,
        4(2), 150-194.

    """

    def __init__(self, dimension=4, lower=-100.0, upper=100.0, *args, **kwargs):
        r"""Initialize Step2 problem..

        Args:
            dimension (Optional[int]): Dimension of the problem.
            lower (Optional[Union[float, Iterable[float]]]): Lower bounds of the problem.
            upper (Optional[Union[float, Iterable[float]]]): Upper bounds of the problem.

        See Also:
            :func:`niapy.problems.Problem.__init__`

        """
        super().__init__(dimension, lower, upper, *args, **kwargs)

    @staticmethod
    def latex_code():
        r"""Return the latex code of the problem.

        Returns:
            str: Latex code.

        """
        return r'''$f(\mathbf{x}) = \sum_{i=1}^D \left( \lfloor x_i + 0.5 \rfloor \right)^2$'''

    def _evaluate(self, x):
        return np.sum(np.floor(x + 0.5) ** 2)


class Step3(Problem):
    r"""Step3 function implementation.

    Date: 2018

    Author: Lucija Brezočnik

    Licence: MIT

    Function: **Step3 function**

        :math:`f(\mathbf{x}) = \sum_{i=1}^D \left( \lfloor x_i^2 \rfloor \right)`

        **Input domain:**
        The function can be defined on any input domain but it is usually
        evaluated on the hypercube :math:`x_i ∈ [-100, 100]`, for all :math:`i = 1, 2,..., D`.

        **Global minimum:** :math:`f(x^*) = 0`, at :math:`x^* = (0,...,0)`

    LaTeX formats:
        Inline:
            $f(\mathbf{x}) = \sum_{i=1}^D \left( \lfloor x_i^2 \rfloor \right)$

        Equation:
            \begin{equation}f(\mathbf{x}) = \sum_{i=1}^D \left(
            \lfloor x_i^2 \rfloor \right)\end{equation}

        Domain:
            $-100 \leq x_i \leq 100$

    Reference paper:
        Jamil, M., and Yang, X. S. (2013).
        A literature survey of benchmark functions for global optimisation problems.
        International Journal of Mathematical Modelling and Numerical Optimisation,
        4(2), 150-194.

    """

    def __init__(self, dimension=4, lower=-100.0, upper=100.0, *args, **kwargs):
        r"""Initialize Step3 problem..

        Args:
            dimension (Optional[int]): Dimension of the problem.
            lower (Optional[Union[float, Iterable[float]]]): Lower bounds of the problem.
            upper (Optional[Union[float, Iterable[float]]]): Upper bounds of the problem.

        See Also:
            :func:`niapy.problems.Problem.__init__`

        """
        super().__init__(dimension, lower, upper, *args, **kwargs)

    @staticmethod
    def latex_code():
        r"""Return the latex code of the problem.

        Returns:
            str: Latex code.

        """
        return r'''$f(\mathbf{x}) = \sum_{i=1}^D \left( \lfloor x_i^2 \rfloor \right)$'''

    def _evaluate(self, x):
        return np.sum(np.floor(x ** 2))



# encoding=utf8

from niapy.algorithms.basic import HarrisHawksOptimization
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class HHOTestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = HarrisHawksOptimization

    def test_custom(self):
        hho_custom = self.algo(population_size=10, levy=0.01, seed=self.seed)
        hho_customc = self.algo(population_size=10, levy=0.01, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, hho_custom, hho_customc, MyProblem())

    def test_griewank(self):
        hho_griewank = self.algo(population_size=10, nFES=4000, nGEN=200, levy=0.01, seed=self.seed)
        hho_griewankc = self.algo(population_size=10, nFES=4000, nGEN=200, levy=0.01, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, hho_griewank, hho_griewankc)

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



# encoding=utf8
from niapy.algorithms.basic import KrillHerd
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class KHTestCase(AlgorithmTestCase):
    r"""Test case for KrillHerdV1 algorithm.

    Date:
        April 2019

    Author:
        Klemen Berkovič

    See Also:
        * :class:`niapy.tests.test_algorithm.AlgorithmTestCase`
    """

    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = KrillHerd

    def test_custom(self):
        kh_custom = self.algo(population_size=10, C_a=2, C_r=0.5, seed=self.seed)
        kh_customc = self.algo(population_size=10, C_a=2, C_r=0.5, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, kh_custom, kh_customc, MyProblem())

    def test_griewank(self):
        kh_griewank = self.algo(population_size=10, C_a=5, C_r=0.5, seed=self.seed)
        kh_griewankc = self.algo(population_size=10, C_a=5, C_r=0.5, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, kh_griewank, kh_griewankc)

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



# encoding=utf8

from niapy.algorithms.basic import DifferentialEvolution, DynNpDifferentialEvolution, AgingNpDifferentialEvolution, \
    MultiStrategyDifferentialEvolution, DynNpMultiStrategyDifferentialEvolution
from niapy.algorithms.basic.de import cross_rand1, cross_rand2, cross_best1, cross_best2, cross_curr2rand1, cross_curr2best1
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class DETestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = DifferentialEvolution

    def test_Custom(self):
        de_custom = self.algo(population_size=10, differential_weight=0.5, crossover_probability=0.9, seed=self.seed)
        de_customc = self.algo(population_size=10, differential_weight=0.5, crossover_probability=0.9, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, de_custom, de_customc, MyProblem())

    def test_griewank(self):
        de_griewank = self.algo(population_size=10, crossover_probability=0.5, differential_weight=0.9, seed=self.seed)
        de_griewankc = self.algo(population_size=10, crossover_probability=0.5, differential_weight=0.9, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, de_griewank, de_griewankc)

    def test_CrossRand1(self):
        de_rand1 = self.algo(population_size=10, strategy=cross_rand1, seed=self.seed)
        de_rand1c = self.algo(population_size=10, strategy=cross_rand1, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, de_rand1, de_rand1c)

    def test_CrossBest1(self):
        de_best1 = self.algo(population_size=10, strategy=cross_best1, seed=self.seed)
        de_best1c = self.algo(population_size=10, strategy=cross_best1, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, de_best1, de_best1c)

    def test_CrossRand2(self):
        de_rand2 = self.algo(population_size=10, strategy=cross_rand2, seed=self.seed)
        de_rand2c = self.algo(population_size=10, strategy=cross_rand2, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, de_rand2, de_rand2c)

    def test_CrossBest2(self):
        de_best2 = self.algo(population_size=10, strategy=cross_best2, seed=self.seed)
        de_best2c = self.algo(population_size=10, strategy=cross_best2, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, de_best2, de_best2c)

    def test_CrossCurr2Rand1(self):
        de_curr2rand1 = self.algo(population_size=10, strategy=cross_curr2rand1, seed=self.seed)
        de_curr2rand1c = self.algo(population_size=10, strategy=cross_curr2rand1, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, de_curr2rand1, de_curr2rand1c)

    def test_CrossCurr2Best1(self):
        de_curr2best1 = self.algo(population_size=10, strategy=cross_curr2best1, seed=self.seed)
        de_curr2best1c = self.algo(population_size=10, strategy=cross_curr2best1, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, de_curr2best1, de_curr2best1c)


class DynNpDETestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = DynNpDifferentialEvolution

    def test_Custom(self):
        de_custom = self.algo(population_size=10, differential_weight=0.5, crossover_probability=0.9, seed=self.seed)
        de_customc = self.algo(population_size=10, differential_weight=0.5, crossover_probability=0.9, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, de_custom, de_customc, MyProblem())

    def test_griewank(self):
        de_griewank = self.algo(population_size=10, crossover_probability=0.5, differential_weight=0.9, seed=self.seed)
        de_griewankc = self.algo(population_size=10, crossover_probability=0.5, differential_weight=0.9, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, de_griewank, de_griewankc, 'griewank')


class ANpDETestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = AgingNpDifferentialEvolution

    def test_Custom(self):
        de_custom = self.algo(population_size=10, differential_weight=0.5, crossover_probability=0.9, seed=self.seed)
        de_customc = self.algo(population_size=10, differential_weight=0.5, crossover_probability=0.9, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, de_custom, de_customc, MyProblem())

    def test_griewank(self):
        de_griewank = self.algo(population_size=10, crossover_probability=0.5, differential_weight=0.9, seed=self.seed)
        de_griewankc = self.algo(population_size=10, crossover_probability=0.5, differential_weight=0.9, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, de_griewank, de_griewankc, 'griewank')


class MsDETestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = MultiStrategyDifferentialEvolution

    def test_Custom(self):
        de_custom = MultiStrategyDifferentialEvolution(population_size=10, differential_weight=0.5, crossover_probability=0.9, seed=self.seed)
        de_customc = MultiStrategyDifferentialEvolution(population_size=10, differential_weight=0.5, crossover_probability=0.9, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, de_custom, de_customc, MyProblem())

    def test_griewank(self):
        de_griewank = MultiStrategyDifferentialEvolution(population_size=10, crossover_probability=0.5, differential_weight=0.9, seed=self.seed)
        de_griewankc = MultiStrategyDifferentialEvolution(population_size=10, crossover_probability=0.5, differential_weight=0.9, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, de_griewank, de_griewankc, 'griewank')


class DynNpMsDETestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = DynNpMultiStrategyDifferentialEvolution

    def test_Custom(self):
        de_custom = self.algo(population_size=10, rp=3, differential_weight=0.5, crossover_probability=0.9, seed=self.seed)
        de_customc = self.algo(population_size=10, rp=3, differential_weight=0.5, crossover_probability=0.9, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, de_custom, de_customc, MyProblem())

    def test_griewank(self):
        de_griewank = self.algo(population_size=10, crossover_probability=0.5, differential_weight=0.9, seed=self.seed)
        de_griewankc = self.algo(population_size=10, crossover_probability=0.5, differential_weight=0.9, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, de_griewank, de_griewankc, 'griewank')

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



# encoding=utf8
from unittest import TestCase

import numpy as np
from numpy.random import default_rng

from niapy.problems import Problem
from niapy.task import Task
from niapy.util.array import full_array


class MyProblem(Problem):
    def __init__(self, dimension=20):
        super().__init__(dimension, -10, 10)

    def _evaluate(self, x):
        return np.sum(x ** 2)


class TaskTestCase(TestCase):
    r"""Test case for testing the Task class.

    Date:
        April 2019

    Author:
        Klemen Berkovič

    See Also:
        * :class:`niapy.util.Task`

    """

    def setUp(self):
        self.D, self.nFES, self.nGEN = 10, 10, 10
        self.Lower, self.Upper = [2, 1, 1], [10, 10, 5]
        self.task = Task(dimension=self.D, lower=self.Lower, upper=self.Upper, problem='sphere', max_evals=self.nFES, max_iters=self.nGEN, cutoff_value=0.0)

    def test_dim_ok(self):
        self.assertEqual(self.D, self.task.dimension)
        self.assertEqual(self.D, self.task.dimension)

    def test_lower(self):
        self.assertTrue(np.array_equal(full_array(self.Lower, self.D), self.task.lower))
        self.assertTrue(np.array_equal(full_array(self.Lower, self.D), self.task.lower))

    def test_upper(self):
        self.assertTrue(np.array_equal(full_array(self.Upper, self.D), self.task.upper))
        self.assertTrue(np.array_equal(full_array(self.Upper, self.D), self.task.upper))

    def test_range(self):
        self.assertTrue(
            np.array_equal(full_array(self.Upper, self.D) - full_array(self.Lower, self.D), self.task.range))
        self.assertTrue(
            np.array_equal(full_array(self.Upper, self.D) - full_array(self.Lower, self.D), self.task.range))

    def test_max_iters(self):
        self.assertEqual(self.nGEN, self.task.max_iters)

    def test_max_evals(self):
        self.assertEqual(self.nFES, self.task.max_evals)

    def test_is_feasible(self):
        x = np.full(self.D, 2)
        self.assertTrue(self.task.is_feasible(x))
        x = np.full(self.D, 3)
        self.assertTrue(self.task.is_feasible(x))
        x = default_rng().uniform(self.task.lower, self.task.upper, self.D)
        self.assertTrue(self.task.is_feasible(x))
        x = np.full(self.D, -20)
        self.assertFalse(self.task.is_feasible(x))
        x = np.full(self.D, 20)
        self.assertFalse(self.task.is_feasible(x))

    def test_next_iter(self):
        for i in range(self.nGEN):
            self.assertFalse(self.task.stopping_condition())
            self.task.next_iter()
        self.assertTrue(self.task.stopping_condition())

    def test_stop_cond_iter(self):
        for i in range(self.nGEN):
            self.assertFalse(self.task.stopping_condition_iter(), msg='Error at %s iteration!!!' % i)
        self.assertTrue(self.task.stopping_condition_iter())

    def test_eval(self):
        x = np.ones(self.D)
        for i in range(self.nFES):
            self.assertAlmostEqual(self.task.eval(x), self.D, msg='Error at %s iteration!!!' % i)
        self.assertTrue(self.task.stopping_condition())

    def test_eval_over_max_evals(self):
        x = np.ones(self.D)
        for i in range(self.nFES):
            self.task.eval(x)
        self.assertEqual(np.inf, self.task.eval(x))
        self.assertTrue(self.task.stopping_condition())

    def test_eval_over_max_iters(self):
        x = np.ones(self.D)
        for i in range(self.nGEN):
            self.task.next_iter()
        self.assertEqual(np.inf, self.task.eval(x))
        self.assertTrue(self.task.stopping_condition())

    def test_evals_count(self):
        x = np.ones(self.D)
        for i in range(self.nFES):
            self.task.eval(x)
            self.assertEqual(self.task.evals, i + 1, 'Error at %s. evaluation' % (i + 1))

    def test_iters_count(self):
        for i in range(self.nGEN):
            self.task.next_iter()
            self.assertEqual(self.task.iters, i + 1, 'Error at %s. iteration' % (i + 1))

    def test_stop_cond_evals(self):
        x = np.ones(self.D)
        for i in range(self.nFES - 1):
            self.task.eval(x)
            self.assertFalse(self.task.stopping_condition())
        self.task.eval(x)
        self.assertTrue(self.task.stopping_condition())

    def test_stop_cond_iters(self):
        for i in range(self.nGEN - 1):
            self.task.next_iter()
            self.assertFalse(self.task.stopping_condition())
        self.task.next_iter()
        self.assertTrue(self.task.stopping_condition())

    def test_stop_cond_cutoff_value(self):
        x = np.ones(self.D)
        for i in range(self.nGEN - 5):
            self.assertFalse(self.task.stopping_condition())
            self.assertEqual(self.D, self.task.eval(x))
            self.task.next_iter()
        x = np.zeros(self.D)
        self.assertEqual(0, self.task.eval(x))
        self.assertTrue(self.task.stopping_condition())
        self.assertEqual(self.nGEN - 5, self.task.iters)

    def test_print_conv_one(self):
        r1, r2 = [], []
        for i in range(self.nFES):
            x = np.full(self.D, 10 - i)
            r1.append(i + 1), r2.append(self.task.eval(x))
        t_r1, t_r2 = self.task.return_conv()
        self.assertTrue(np.array_equal(r1, t_r1))
        self.assertTrue(np.array_equal(r2, t_r2))

    def test_print_conv_two(self):
        r1, r2 = [], []
        for i in range(self.nFES):
            x = np.full(self.D, 10 - i if i not in (3, 4, 5) else 4)
            r1.append(i + 1), r2.append(self.task.eval(x))
        t_r1, t_r2 = self.task.return_conv()
        self.assertTrue(np.array_equal(r2, t_r2))
        self.assertTrue(np.array_equal(r1, t_r1))

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



# encoding=utf8
from niapy.algorithms.basic import GravitationalSearchAlgorithm
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class GSATestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = GravitationalSearchAlgorithm

    def test_Custom(self):
        gsa_custom = self.algo(population_size=10, seed=self.seed)
        gsa_customc = self.algo(population_size=10, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, gsa_custom, gsa_customc, MyProblem())

    def test_griewank(self):
        gsa_griewank = self.algo(population_size=10, seed=self.seed)
        gsa_griewankc = self.algo(population_size=10, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, gsa_griewank, gsa_griewankc)

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



"""Unit tests configuration file."""

import logging


def pytest_configure(config):
    """Disable verbose output when running tests."""
    logging.basicConfig(level=logging.DEBUG)

#     terminal = config.pluginmanager.getplugin('terminal')
#     base = terminal.TerminalReporter

#     class QuietReporter(base):
#         """Reporter that only shows dots when running tests."""

#         def __init__(self, *args, **kwargs):
#             super(QuietReporter, self).__init__(*args, **kwargs)
#             self.verbosity = 0
#             self.showlongtestinfo = False
#             self.showfspath = False

#     terminal.TerminalReporter = QuietReporter



# pylint: disable=line-too-long
from niapy.algorithms.modified import AdaptiveBatAlgorithm
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class ABATestCase(AlgorithmTestCase):
    r"""Test case for AdaptiveBatAlgorithm algorithm.

    Date:
        April 2019

    Author:
        Klemen Berkovic

    See Also:
        * :class:`niapy.algorithms.modified.AdaptiveBatAlgorithm`
    """

    def test_custom(self):
        aba_custom = AdaptiveBatAlgorithm(population_size=10, A=.75, epsilon=2, alpha=0.65, r=0.7, Qmin=0.0, Qmax=2.0,
                                          seed=self.seed)
        aba_customc = AdaptiveBatAlgorithm(population_size=10, A=.75, epsilon=2, alpha=0.65, r=0.7, Qmin=0.0, Qmax=2.0,
                                           seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, aba_custom, aba_customc, MyProblem())

    def test_griewank(self):
        aba_griewank = AdaptiveBatAlgorithm(population_size=10, A=0.5, r=0.5, F=0.5, CR=0.9, Qmin=0.0, Qmax=2.0, seed=self.seed)
        aba_griewankc = AdaptiveBatAlgorithm(population_size=10, A=0.5, r=0.5, F=0.5, CR=0.9, Qmin=0.0, Qmax=2.0, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, aba_griewank, aba_griewankc)



# encoding=utf8

"""Implementations of Infinity function."""

import numpy as np
from niapy.problems.problem import Problem

__all__ = ['Infinity']


class Infinity(Problem):
    r"""Implementations of Infinity function.

    Date: 2018

    Author: Klemen Berkovič

    License: MIT

    Function:
    **Infinity Function**

        :math:`f(\textbf{x}) = \sum_{i = 1}^D x_i^6 \left( \sin \left( \frac{1}{x_i} \right) + 2 \right)`

        **Input domain:**
        The function can be defined on any input domain but it is usually
        evaluated on the hypercube :math:`x_i ∈ [-1, 1]`, for all :math:`i = 1, 2,..., D`.

        **Global minimum:**
        :math:`f(x^*) = 0`, at :math:`x^* = (420.968746,...,420.968746)`

    LaTeX formats:
        Inline:
            $f(\textbf{x}) = \sum_{i = 1}^D x_i^6 \left( \sin \left( \frac{1}{x_i} \right) + 2 \right)$

        Equation:
            \begin{equation} f(\textbf{x}) = \sum_{i = 1}^D x_i^6 \left( \sin \left( \frac{1}{x_i} \right) + 2 \right) \end{equation}

        Domain:
            $-1 \leq x_i \leq 1$

    Reference:
        http://infinity77.net/global_optimization/test_functions_nd_I.html#go_benchmark.Infinity

    """

    def __init__(self, dimension=2, lower=-1.0, upper=1.0, *args, **kwargs):
        r"""Initialize Infinity problem..

        Args:
            dimension (Optional[int]): Dimension of the problem.
            lower (Optional[Union[float, Iterable[float]]]): Lower bounds of the problem.
            upper (Optional[Union[float, Iterable[float]]]): Upper bounds of the problem.

        See Also:
            :func:`niapy.problems.Problem.__init__`

        """
        super().__init__(dimension, lower, upper, *args, **kwargs)

    @staticmethod
    def latex_code():
        r"""Return the latex code of the problem.

        Returns:
            str: Latex code.

        """
        return r'''$f(\textbf{x}) = \sum_{i = 1}^D x_i^6 \left( \sin \left( \frac{1}{x_i} \right) + 2 \right)$'''

    def _evaluate(self, x):
        return np.sum(x ** 6.0 * (np.sin(1.0 / x) + 2.0))

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



# encoding=utf8
from niapy.algorithms.basic import ForestOptimizationAlgorithm
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class FOATestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = ForestOptimizationAlgorithm

    def test(self):
        foa = self.algo(population_size=10, lifetime=5, local_seeding_changes=1, global_seeding_changes=1, area_limit=20, transfer_rate=0.35, seed=self.seed)
        foac = self.algo(population_size=10, lifetime=5, local_seeding_changes=1, global_seeding_changes=1, area_limit=20, transfer_rate=0.35, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, foa, foac, MyProblem())

    def test_griewank(self):
        foa_griewank = self.algo(population_size=10, lifetime=5, local_seeding_changes=1, global_seeding_changes=1, area_limit=20, transfer_rate=0.35, seed=self.seed)
        foa_griewankc = self.algo(population_size=10, lifetime=5, local_seeding_changes=1, global_seeding_changes=1, area_limit=20, transfer_rate=0.35, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, foa_griewank, foa_griewankc)

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



# encoding=utf8

import logging
from queue import Queue
from threading import Thread
from unittest import TestCase

import numpy as np
from numpy.random import default_rng

from niapy.algorithms.algorithm import Individual, Algorithm
from niapy.problems import Problem
from niapy.task import Task
from niapy.util import objects_to_array

logging.basicConfig()
logger = logging.getLogger('niapy.test')
logger.setLevel('INFO')


class MyProblem(Problem):
    r"""Testing problem class.

    Date:
        April 2019

    Author:
        Klemen Berkovič

    See Also:
        * :class:`niapy.problems.Problem`

    """

    def __init__(self, dimension=10, *_args, **_kwargs):
        super().__init__(dimension, -5.12, 5.12)

    def _evaluate(self, x):
        return np.sum(x ** 2)


class IndividualTestCase(TestCase):
    r"""Test case for testing Individual class.

    Date:
        April 2019

    Author:
        Klemen Berkovič

    See Also:
        * :class:`niapy.algorithms.Individual`

    """

    def setUp(self):
        self.dimension = 20
        rng = default_rng()
        self.x = rng.uniform(-100, 100, self.dimension)
        self.task = Task(max_evals=230, max_iters=np.inf, problem=MyProblem(self.dimension))
        self.s1 = Individual(x=self.x, e=False)
        self.s2 = Individual(task=self.task, rng=rng)
        self.s3 = Individual(task=self.task)

    def test_generate_solution(self):
        self.assertTrue(self.task.is_feasible(self.s2))
        self.assertTrue(self.task.is_feasible(self.s3))

    def test_evaluate(self):
        self.s1.evaluate(self.task)
        self.assertAlmostEqual(self.s1.f, self.task.eval(self.x))

    def test_repair(self):
        s = Individual(x=np.full(self.dimension, 100))
        self.assertFalse(self.task.is_feasible(s.x))

    def test_eq(self):
        self.assertFalse(self.s1 == self.s2)
        self.assertTrue(self.s1 == self.s1)
        s = Individual(x=self.s1.x)
        self.assertTrue(s == self.s1)

    def test_str(self):
        self.assertEqual(str(self.s1), '%s -> %s' % (self.x, np.inf))

    def test_getitem(self):
        for i in range(self.dimension):
            self.assertEqual(self.s1[i], self.x[i])

    def test_len(self):
        self.assertEqual(len(self.s1), len(self.x))


def init_pop_numpy(task, population_size, **_kwargs):
    r"""Custom population initialization function for numpy individual type.

    Args:
        task (Task): Optimization task.
        population_size (int): Population size.

    Returns:
        Tuple[numpy.ndarray, numpy.ndarray[float]):
            1. Initialized population.
            2. Initialized populations fitness/function values.

    """
    pop = np.zeros((population_size, task.dimension))
    fpop = np.apply_along_axis(task.eval, 1, pop)
    return pop, fpop


def init_pop_individual(task, population_size, individual_type, **_kwargs):
    r"""Custom population initialization function for numpy individual type.

    Args:
        task (Task): Optimization task.
        population_size (int): Population size.
        individual_type (Type[Individual]): Type of individual in population.

    Returns:
        Tuple[numpy.ndarray, numpy.ndarray[float]):
            1. Initialized population.
            2. Initialized populations fitness/function values.

    """
    pop = objects_to_array([individual_type(x=np.zeros(task.dimension), task=task) for _ in range(population_size)])
    return pop, np.asarray([x.f for x in pop])


class AlgorithmBaseTestCase(TestCase):
    r"""Test case for testing Algorithm class.

    Date:
        April 2019

    Author:
        Klemen Berkovič

    Attributes:
        seed (int): Starting seed of random generator.
        rng (numpy.random.Generator): Random generator.
        a (Algorithm): Algorithm to use for testing.

    See Also:
        * :class:`niapy.algorithms.Individual`

    """

    def setUp(self):
        self.seed = 1
        self.rng = default_rng(self.seed)
        self.a = Algorithm(seed=self.seed)

    def test_algorithm_info(self):
        r"""Check if method works fine."""
        i = Algorithm.info()
        self.assertIsNotNone(i)

    def test_algorithm_getParameters(self):
        r"""Check if method works fine."""
        algo = Algorithm()
        params = algo.get_parameters()
        self.assertIsNotNone(params)

    def test_init_population_numpy(self):
        r"""Test if custom generation initialization works ok."""
        a = Algorithm(population_size=10, initialization_function=init_pop_numpy)
        t = Task(problem=MyProblem(dimension=20))
        self.assertTrue(np.array_equal(np.zeros((10, t.dimension)), a.init_population(t)[0]))

    def test_init_population_individual(self):
        r"""Test if custom generation initialization works ok."""
        a = Algorithm(population_size=10, initialization_function=init_pop_individual, individual_type=Individual)
        t = Task(problem=MyProblem(dimension=20))
        i = Individual(x=np.zeros(t.dimension), task=t)
        pop, fpop, d = a.init_population(t)
        for e in pop:
            self.assertEqual(i, e)

    def test_set_parameters(self):
        self.a.set_parameters(t=None, a=20)
        self.assertRaises(AttributeError, lambda: self.assertEqual(self.a.a, None))

    def test_integers(self):
        o = self.a.integers(low=10, high=20, size=[10, 10])
        self.assertEqual(o.shape, (10, 10))
        self.assertTrue(np.array_equal(self.rng.integers(10, 20, (10, 10)), o))
        o = self.a.integers(low=10, high=20, size=(10, 5))
        self.assertEqual(o.shape, (10, 5))
        self.assertTrue(np.array_equal(self.rng.integers(10, 20, (10, 5)), o))
        o = self.a.integers(low=10, high=20, size=10)
        self.assertEqual(o.shape, (10,))
        self.assertTrue(np.array_equal(self.rng.integers(10, 20, 10), o))

    def test_standard_normal(self):
        a = self.a.standard_normal([1, 2])
        self.assertEqual(a.shape, (1, 2))
        self.assertTrue(np.array_equal(self.rng.standard_normal((1, 2)), a))
        a = self.a.standard_normal(1)
        self.assertEqual(len(a), 1)
        self.assertTrue(np.array_equal(self.rng.standard_normal(1), a))
        a = self.a.standard_normal(2)
        self.assertEqual(len(a), 2)
        self.assertTrue(np.array_equal(self.rng.standard_normal(2), a))
        a = self.a.standard_normal()
        self.assertIsInstance(a, float)
        self.assertTrue(np.array_equal(self.rng.standard_normal(), a))

    def test_uniform(self):
        a = self.a.uniform(-10, 10, [10, 10])
        self.assertEqual(a.shape, (10, 10))
        self.assertTrue(np.array_equal(self.rng.uniform(-10, 10, (10, 10)), a))
        a = self.a.uniform(4, 10, (4, 10))
        self.assertEqual(len(a), 4)
        self.assertEqual(len(a[0]), 10)
        self.assertTrue(np.array_equal(self.rng.uniform(4, 10, (4, 10)), a))
        a = self.a.uniform(1, 4, 2)
        self.assertEqual(len(a), 2)
        self.assertTrue(np.array_equal(self.rng.uniform(1, 4, 2), a))
        a = self.a.uniform(10, 100)
        self.assertIsInstance(a, float)
        self.assertEqual(self.rng.uniform(10, 100), a)

    def test_normal(self):
        a = self.a.normal(-10, 10, [10, 10])
        self.assertEqual(a.shape, (10, 10))
        self.assertTrue(np.array_equal(self.rng.normal(-10, 10, (10, 10)), a))
        a = self.a.normal(4, 10, (4, 10))
        self.assertEqual(len(a), 4)
        self.assertEqual(len(a[0]), 10)
        self.assertTrue(np.array_equal(self.rng.normal(4, 10, (4, 10)), a))
        a = self.a.normal(1, 4, 2)
        self.assertEqual(len(a), 2)
        self.assertTrue(np.array_equal(self.rng.normal(1, 4, 2), a))
        a = self.a.normal(10, 100)
        self.assertIsInstance(a, float)
        self.assertEqual(self.rng.normal(10, 100), a)


class TestingTask(Task, TestCase):
    r"""Testing task.

    Date:
        April 2019

    Author:
        Klemen Berkovič

    See Also:
        * :class:`niapy.task.Task`

    """

    def eval(self, x):
        r"""Check if is algorithm trying to evaluate solution out of bounds."""
        self.assertTrue(self.is_feasible(x), 'Solution %s is not in feasible space!!!' % x)
        return super().eval(x)


class AlgorithmTestCase(TestCase):
    r"""Base class for testing other algorithms.

    Date:
        April 2019

    Author:
        Klemen Berkovič

    Attributes:
        dimensions (List[int]): Dimension of problem.
        max_iters (int): Number of generations/iterations.
        max_evals (int): Number of function evaluations.
        seed (int): Starting seed of random generator.

    See Also:
        * :class:`niapy.algorithms.Algorithm`

    """

    def setUp(self):
        r"""Setup basic parameters of the algorithm run."""
        self.dimensions = (10, 40)
        self.max_iters = 1000
        self.max_evals = 1000
        self.seed = 1
        self.algo = Algorithm

    def test_algorithm_info(self):
        r"""Test if algorithm info works fine."""
        info = self.algo.info()
        self.assertIsNotNone(info)

    def test_algorithm_get_parameters(self):
        r"""Test if algorithms parameters values are fine."""
        params = self.algo().get_parameters()
        self.assertIsNotNone(params)

    def setUpTasks(self, dimension, problem='griewank', max_evals=None, max_iters=None):
        r"""Setup optimization tasks for testing.

        Args:
            dimension (int): Dimension of the problem.
            problem (Optional[str, class]): Optimization problem to use.
            max_evals (int): Number of fitness/objective function evaluations.
            max_iters (int): Number of generations.

        Returns:
            Tuple[Task, Task]: Two testing tasks.

        """
        if isinstance(problem, Problem):
            cls = problem.__class__
            problem = cls(dimension=dimension)
            dimension = None
        max_evals = self.max_evals if max_evals is None else max_evals
        max_iters = self.max_iters if max_iters is None else max_iters
        task1 = TestingTask(dimension=dimension, max_evals=max_evals, max_iters=max_iters, problem=problem)
        task2 = TestingTask(dimension=dimension, max_evals=max_evals, max_iters=max_iters, problem=problem)
        return task1, task2

    def test_algorithm_run(self, a=None, b=None, problem='griewank', max_evals=None, max_iters=None):
        r"""Run main testing of algorithm.

        Args:
            a (Algorithm): First instance of algorithm.
            b (Algorithm): Second instance of algorithm.
            problem (Union[Problem, str]): Problem to use for testing.
            max_evals (int): Number of function evaluations.
            max_iters (int): Number of algorithm generations/iterations.

        """
        if a is None or b is None:
            return
        for D in self.dimensions:
            task1, task2 = self.setUpTasks(D, problem, max_evals=max_evals, max_iters=max_iters)
            # x = a.run(task1) # For debugging purposes
            # y = b.run(task2) # For debugging purposes
            q = Queue(maxsize=2)
            thread1 = Thread(target=lambda algorithm, task, queue: queue.put(algorithm.run(task)), args=(a, task1, q))
            thread2 = Thread(target=lambda algorithm, task, queue: queue.put(algorithm.run(task)), args=(b, task2, q))
            thread1.start()
            thread2.start()
            thread1.join()
            thread2.join()
            x = q.get(block=True)
            y = q.get(block=True)
            if a.bad_run():
                raise a.exception
            self.assertFalse(a.bad_run() or b.bad_run(),
                             "Something went wrong at runtime of the algorithm --> %s" % a.exception)
            self.assertIsNotNone(x)
            self.assertIsNotNone(y)
            logger.info('%s\n%s -> %s\n%s -> %s' % (task1.problem.name(), x[0], x[1], y[0], y[1]))
            self.assertAlmostEqual(task1.problem.evaluate(x[0].x if isinstance(x[0], Individual) else x[0]),
                                   x[1], msg='Best individual fitness values does not mach the given one')
            self.assertAlmostEqual(task1.x_f, x[1],
                                   msg='While running the algorithm, algorithm got better individual with fitness: %s' % task1.x_f)
            self.assertTrue(np.array_equal(x[0], y[0]),
                            'Results can not be reproduced, check usages of random number generator')
            self.assertAlmostEqual(x[1], y[1], msg='Results can not be reproduced or bad function value')
            self.assertTrue(self.max_evals if max_evals is None else max_evals >= task1.evals)
            self.assertEqual(task1.evals, task2.evals)
            self.assertTrue(self.max_iters if max_iters is None else max_iters >= task1.iters)
            self.assertEqual(task1.iters, task2.iters)

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



# encoding=utf8
from niapy.algorithms.basic import ParticleSwarmOptimization, ParticleSwarmAlgorithm, \
    OppositionVelocityClampingParticleSwarmOptimization, CenterParticleSwarmOptimization, \
    MutatedParticleSwarmOptimization, MutatedCenterParticleSwarmOptimization, \
    ComprehensiveLearningParticleSwarmOptimizer, MutatedCenterUnifiedParticleSwarmOptimization
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class PSOTestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = ParticleSwarmOptimization

    def test_algorithm_info(self):
        al = self.algo.info()
        self.assertIsNotNone(al)

    def test_custom(self):
        pso_custom = self.algo(population_size=10, c1=2.0, c2=2.0, w=0.7, min_velocity=-4, max_velocity=4, seed=self.seed)
        pso_customc = self.algo(population_size=10, c1=2.0, c2=2.0, w=0.7, min_velocity=-4, max_velocity=4, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, pso_custom, pso_customc, MyProblem())

    def test_griewank(self):
        pso_griewank = self.algo(population_size=10, c1=2.0, c2=2.0, w=0.7, min_velocity=-4, max_velocity=4, seed=self.seed)
        pso_griewankc = self.algo(population_size=10, c1=2.0, c2=2.0, w=0.7, min_velocity=-4, max_velocity=4, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, pso_griewank, pso_griewankc)


class PSATestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = ParticleSwarmAlgorithm

    def test_algorithm_info(self):
        al = ParticleSwarmAlgorithm.info()
        self.assertIsNotNone(al)

    def test_custom(self):
        wvcpso_custom = ParticleSwarmAlgorithm(population_size=10, c1=2.0, c2=2.0, w=0.7, min_velocity=-4, max_velocity=4, seed=self.seed)
        wvcpso_customc = ParticleSwarmAlgorithm(population_size=10, c1=2.0, c2=2.0, w=0.7, min_velocity=-4, max_velocity=4, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, wvcpso_custom, wvcpso_customc, MyProblem())

    def test_griewank(self):
        wvcpso_griewank = ParticleSwarmAlgorithm(population_size=10, c1=2.0, c2=2.0, w=0.7, min_velocity=-4, max_velocity=4, seed=self.seed)
        wvcpso_griewankc = ParticleSwarmAlgorithm(population_size=10, c1=2.0, c2=2.0, w=0.7, min_velocity=-4, max_velocity=4, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, wvcpso_griewank, wvcpso_griewankc)


class OVCPSOTestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = OppositionVelocityClampingParticleSwarmOptimization

    def test_algorithm_info(self):
        al = self.algo.info()
        self.assertIsNotNone(al)

    def test_custom(self):
        wvcpso_custom = self.algo(population_size=10, c1=2.0, c2=2.0, w=0.7, min_velocity=-4, max_velocity=4, seed=self.seed)
        wvcpso_customc = self.algo(population_size=10, c1=2.0, c2=2.0, w=0.7, min_velocity=-4, max_velocity=4, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, wvcpso_custom, wvcpso_customc, MyProblem())

    def test_griewank(self):
        wvcpso_griewank = self.algo(population_size=10, c1=2.0, c2=2.0, w=0.7, min_velocity=-4, max_velocity=4, seed=self.seed)
        wvcpso_griewankc = self.algo(population_size=10, c1=2.0, c2=2.0, w=0.7, min_velocity=-4, max_velocity=4, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, wvcpso_griewank, wvcpso_griewankc)


class CPSOTestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = CenterParticleSwarmOptimization

    def test_algorithm_info(self):
        al = self.algo.info()
        self.assertIsNotNone(al)

    def test_custom(self):
        cpso_custom = self.algo(population_size=10, c1=2.0, c2=2.0, w=0.7, min_velocity=-4, max_velocity=4, seed=self.seed)
        cpso_customc = self.algo(population_size=10, c1=2.0, c2=2.0, w=0.7, min_velocity=-4, max_velocity=4, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, cpso_custom, cpso_customc, MyProblem())

    def test_griewank(self):
        cpso_griewank = self.algo(population_size=10, c1=2.0, c2=2.0, w=0.7, min_velocity=-4, max_velocity=4, seed=self.seed)
        cpso_griewankc = self.algo(population_size=10, c1=2.0, c2=2.0, w=0.7, min_velocity=-4, max_velocity=4, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, cpso_griewank, cpso_griewankc)


class MPSOTestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = MutatedParticleSwarmOptimization

    def test_algorithm_info(self):
        al = MutatedParticleSwarmOptimization.info()
        self.assertIsNotNone(al)

    def test_custom(self):
        mpso_custom = MutatedParticleSwarmOptimization(population_size=10, c1=2.0, c2=2.0, w=0.7, min_velocity=-4, max_velocity=4, seed=self.seed)
        mpso_customc = MutatedParticleSwarmOptimization(population_size=10, c1=2.0, c2=2.0, w=0.7, min_velocity=-4, max_velocity=4, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, mpso_custom, mpso_customc, MyProblem())

    def test_griewank(self):
        mpso_griewank = MutatedParticleSwarmOptimization(population_size=10, c1=2.0, c2=2.0, w=0.7, min_velocity=-4, max_velocity=4, seed=self.seed)
        mpso_griewankc = MutatedParticleSwarmOptimization(population_size=10, c1=2.0, c2=2.0, w=0.7, min_velocity=-4, max_velocity=4, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, mpso_griewank, mpso_griewankc)


class MCPSOTestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = MutatedCenterParticleSwarmOptimization

    def test_algorithm_info(self):
        al = self.algo.info()
        self.assertIsNotNone(al)

    def test_custom(self):
        mcpso_custom = self.algo(population_size=10, c1=2.0, c2=2.0, w=0.7, min_velocity=-4, max_velocity=4, seed=self.seed)
        mcpso_customc = self.algo(population_size=10, c1=2.0, c2=2.0, w=0.7, min_velocity=-4, max_velocity=4, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, mcpso_custom, mcpso_customc, MyProblem())

    def test_griewank(self):
        mcpso_griewank = self.algo(population_size=10, c1=2.0, c2=2.0, w=0.7, min_velocity=-4, max_velocity=4, seed=self.seed)
        mcpso_griewankc = self.algo(population_size=10, c1=2.0, c2=2.0, w=0.7, min_velocity=-4, max_velocity=4, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, mcpso_griewank, mcpso_griewankc)


class MCUPSOTestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = MutatedCenterUnifiedParticleSwarmOptimization

    def test_algorithm_info(self):
        al = self.algo.info()
        self.assertIsNotNone(al)

    def test_custom(self):
        mcupso_custom = self.algo(population_size=10, c1=2.0, c2=2.0, w=0.7, min_velocity=-4, max_velocity=4, seed=self.seed)
        mcupso_customc = self.algo(population_size=10, c1=2.0, c2=2.0, w=0.7, min_velocity=-4, max_velocity=4, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, mcupso_custom, mcupso_customc, MyProblem())

    def test_griewank(self):
        mcupso_griewank = self.algo(population_size=10, c1=2.0, c2=2.0, w=0.7, min_velocity=-4, max_velocity=4, seed=self.seed)
        mcupso_griewankc = self.algo(population_size=10, c1=2.0, c2=2.0, w=0.7, min_velocity=-4, max_velocity=4, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, mcupso_griewank, mcupso_griewankc)


class CLPSOTestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = ComprehensiveLearningParticleSwarmOptimizer

    def test_algorithm_info(self):
        al = self.algo.info()
        self.assertIsNotNone(al)

    def test_custom(self):
        clpso_custom = self.algo(population_size=10, c1=2.0, c2=2.0, w=0.7, min_velocity=-4, max_velocity=4, seed=self.seed)
        clpso_customc = self.algo(population_size=10, c1=2.0, c2=2.0, w=0.7, min_velocity=-4, max_velocity=4, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, clpso_custom, clpso_customc, MyProblem())

    def test_griewank(self):
        clpso_griewank = self.algo(population_size=10, c1=2.0, c2=2.0, w=0.7, min_velocity=-4, max_velocity=4, seed=self.seed)
        clpso_griewankc = self.algo(population_size=10, c1=2.0, c2=2.0, w=0.7, min_velocity=-4, max_velocity=4, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, clpso_griewank, clpso_griewankc)

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



# encoding=utf8
from niapy.algorithms.modified import HybridSelfAdaptiveBatAlgorithm
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class HSABATestCase(AlgorithmTestCase):
    r"""Test case for HybridSelfAdaptiveBatAlgorithm algorithm.

    Date:
        April 2019

    Author:
        Klemen Berkovič

    See Also:
        * :class:`niapy.algorithms.modified.HybridSelfAdaptiveBatAlgorithm`

    """

    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = HybridSelfAdaptiveBatAlgorithm

    def test_algorithm_info(self):
        """Test case for algorithm info."""
        i = self.algo.info()
        self.assertIsNotNone(i)

    def test_custom(self):
        """Test case for running algorithm on custom problem."""
        hsaba_custom = self.algo(population_size=10, Limit=2, seed=self.seed)
        hsaba_customc = self.algo(population_size=10, Limit=2, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, hsaba_custom, hsaba_customc, MyProblem())

    def test_griewank(self):
        """Test case for running algorithm on griewank problem."""
        hsaba_griewank = self.algo(population_size=10, seed=self.seed)
        hsaba_griewankc = self.algo(population_size=10, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, hsaba_griewank, hsaba_griewankc)

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



# pylint: disable=line-too-long
from niapy.algorithms.modified import SelfAdaptiveBatAlgorithm
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class HBATestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = SelfAdaptiveBatAlgorithm

    def test_custom(self):
        hba_custom = self.algo(population_size=10, starting_loudness=0.5, pulse_rate=0.5, min_frequency=0.0, max_frequency=2.0, seed=self.seed)
        hba_customc = self.algo(population_size=10, starting_loudness=0.5, pulse_rate=0.5, min_frequency=0.0, max_frequency=2.0, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, hba_custom, hba_customc, MyProblem())

    def test_griewank(self):
        hba_griewank = self.algo(population_size=10, starting_loudness=0.5, pulse_rate=0.5, min_frequency=0.0, max_frequency=2.0, seed=self.seed)
        hba_griewankc = self.algo(population_size=10, starting_loudness=0.5, pulse_rate=0.5, min_frequency=0.0, max_frequency=2.0, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, hba_griewank, hba_griewankc)



# encoding=utf8
from unittest import TestCase

import numpy as np
from numpy.random import default_rng

from niapy.algorithms.basic import MonkeyKingEvolutionV1, MonkeyKingEvolutionV2, MonkeyKingEvolutionV3
from niapy.algorithms.basic.mke import MkeSolution
from niapy.task import Task
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class MkeSolutionTestCase(TestCase):
    def setUp(self):
        self.D = 20
        self.x, self.task = default_rng().uniform(-2, 2, self.D), Task(problem=MyProblem(self.D))
        self.sol1, self.sol2, self.sol3 = MkeSolution(x=self.x, e=False), MkeSolution(task=self.task), MkeSolution(
            x=self.x, e=False)

    def test_uPersonalBest(self):
        self.sol2.update_personal_best()
        self.assertTrue(np.array_equal(self.sol2.x, self.sol2.x_pb))
        self.assertEqual(self.sol2.f_pb, self.sol2.f)
        self.sol3.evaluate(self.task)
        self.sol3.x = np.full(self.task.dimension, -5.11)
        self.sol3.evaluate(self.task)
        self.sol3.update_personal_best()
        self.assertTrue(np.array_equal(self.sol3.x, self.sol3.x_pb))
        self.assertEqual(self.sol3.f_pb, self.sol3.f)


class MKEv1TestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = MonkeyKingEvolutionV1

    def test_custom(self):
        mke_custom = self.algo(population_size=10, C_a=2, C_r=0.5, seed=self.seed)
        mke_customc = self.algo(population_size=10, C_a=2, C_r=0.5, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, mke_custom, mke_customc, MyProblem())

    def test_griewank(self):
        mke_griewank = self.algo(population_size=10, C_a=5, C_r=0.5, seed=self.seed)
        mke_griewankc = self.algo(population_size=10, C_a=5, C_r=0.5, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, mke_griewank, mke_griewankc)


class MKEv2TestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = MonkeyKingEvolutionV2

    def test_custom(self):
        mke_custom = self.algo(population_size=10, C_a=2, C_r=0.5, seed=self.seed)
        mke_customc = self.algo(population_size=10, C_a=2, C_r=0.5, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, mke_custom, mke_customc, MyProblem())

    def test_griewank(self):
        mke_griewank = self.algo(population_size=10, C_a=5, C_r=0.5, seed=self.seed)
        mke_griewankc = self.algo(population_size=10, C_a=5, C_r=0.5, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, mke_griewank, mke_griewankc)


class MKEv3TestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = MonkeyKingEvolutionV3

    def test_custom(self):
        mke_custom = self.algo(population_size=10, C_a=2, C_r=0.5, seed=self.seed)
        mke_customc = self.algo(population_size=10, C_a=2, C_r=0.5, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, mke_custom, mke_customc, MyProblem())

    def test_griewank(self):
        mke_griewank = self.algo(population_size=10, C_a=5, C_r=0.5, seed=self.seed)
        mke_griewankc = self.algo(population_size=10, C_a=5, C_r=0.5, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, mke_griewank, mke_griewankc)

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



# encoding=utf8
from unittest import TestCase

from niapy.util import get_argparser, get_args, get_args_dict


class ArgParserTestCase(TestCase):
    def setUp(self):
        self.parser = get_argparser()

    def test_parser(self):
        self.assertTrue(self.parser)

    def test_getArgs(self):
        args = get_args(['-d', '10', '--max-evals', '100000000', '-a', 'SCA'])
        self.assertTrue(args)
        self.assertEqual(args.dimension, 10)
        self.assertEqual(args.max_evals, 100000000)
        self.assertEqual(args.algo, 'SCA')

    def test_getDictArgs(self):
        args = get_args_dict(['-d', '10', '--max-evals', '100000000', '-a', 'SCA'])
        self.assertTrue(args)
        self.assertEqual(args['dimension'], 10)
        self.assertEqual(args['max_evals'], 100000000)
        self.assertEqual(args['algo'], 'SCA')
        self.assertEqual(args['seed'], [None])

    def test_getDictArgs_seed(self):
        args = get_args_dict(['-d', '10', '--max-evals', '100000000', '-a', 'SCA', '--seed', '1'])
        self.assertTrue(args)
        self.assertEqual(args['dimension'], 10)
        self.assertEqual(args['max_evals'], 100000000)
        self.assertEqual(args['algo'], 'SCA')
        self.assertEqual(args['seed'], [1])

    def test_getDictArgs_seed_fine_two(self):
        args = get_args_dict(['-d', '10', '--max-evals', '100000000', '-a', 'SCA', '--seed', '1', '234', '231523'])
        self.assertTrue(args)
        self.assertEqual(args['dimension'], 10)
        self.assertEqual(args['max_evals'], 100000000)
        self.assertEqual(args['algo'], 'SCA')
        self.assertEqual(args['seed'], [1, 234, 231523])

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



# encoding=utf8

from math import pow
from unittest import TestCase

import numpy as np

from niapy.util.factory import get_problem


class TestProblemFunctions(TestCase):
    """Testing the problems."""

    def setUp(self):
        """Set up the tests."""
        self.dimension = 5
        self.array = np.asarray([0, 0, 0, 0, 0])
        self.array2 = np.asarray([1, 1, 1, 1, 1])
        self.array3 = np.asarray([420.968746, 420.968746, 420.968746, 420.968746, 420.968746])
        self.array4 = np.asarray([-2.903534, -2.903534])
        self.array5 = np.asarray([-0.5, -0.5, -0.5, -0.5, -0.5])
        self.array6 = np.asarray([-1, -1, -1, -1, -1])
        self.array7 = np.asarray([2, 2, 2, 2, 2])
        self.array8 = np.asarray(
            [7.9170526982459462172, 7.9170526982459462172, 7.9170526982459462172, 7.9170526982459462172,
             7.9170526982459462172])
        self.array9 = np.asarray([-5.12, -5.12, -5.12, -5.12, -5.12])
        self.array10 = np.asarray([1, 2, 3, 4, 5])

    def test_rastrigin(self):
        """Test the rastrigin function."""
        rastrigin = get_problem('rastrigin', dimension=self.dimension)
        self.assertEqual(rastrigin(self.array), 0.0)

    def test_rosenbrock(self):
        """Test the rosenbrock function."""
        fun = get_problem('rosenbrock', self.dimension)
        self.assertEqual(fun(self.array2), 0.0)

    def test_griewank(self):
        """Test the griewank function."""
        fun = get_problem('griewank', self.dimension)
        self.assertEqual(fun(self.array), 0.0)

    def test_sphere(self):
        """Test the sphere function."""
        fun = get_problem('sphere', self.dimension)
        self.assertEqual(fun(self.array), 0.0)

    def test_ackley(self):
        """Test the ackley function."""
        fun = get_problem('ackley', self.dimension)
        self.assertAlmostEqual(fun(self.array), 0.0, places=10)

    def test_schwefel(self):
        """Test the schwefel function."""
        fun = get_problem('schwefel', self.dimension)
        self.assertAlmostEqual(fun(self.array3), 0.0, places=3)

    def test_schwefel221(self):
        """Test the schwefel 221 function."""
        fun = get_problem('schwefel221', self.dimension)
        self.assertEqual(fun(self.array), 0.0)

    def test_schwefel222(self):
        """Test the schwefel 222 function."""
        fun = get_problem('schwefel222', self.dimension)
        self.assertEqual(fun(self.array), 0.0)

    def test_whitley(self):
        """Test the whitley function."""
        fun = get_problem('whitley', self.dimension)
        self.assertEqual(fun(self.array2), 0.0)

    def test_styblinski_tang(self):
        """Test the styblinski tang function."""
        fun = get_problem('styblinski_tang', dimension=2)
        self.assertAlmostEqual(fun(self.array4), -78.332, places=3)

    def test_sum_squares(self):
        """Test the sum squares function."""
        fun = get_problem('sum_squares', self.dimension)
        self.assertEqual(fun(self.array), 0.0)

    def test_stepint(self):
        """Test the stepint function."""
        fun = get_problem('stepint', self.dimension)
        self.assertEqual(fun(self.array9), -5.0)

    def test_step(self):
        """Test the step function."""
        fun = get_problem('step', self.dimension)
        self.assertEqual(fun(self.array), 0.0)

    def test_step2(self):
        """Test the step 2 function."""
        fun = get_problem('step2', self.dimension)
        self.assertEqual(fun(self.array5), 0.0)

    def test_step3(self):
        """Test the step3 function."""
        fun = get_problem('step3', self.dimension)
        self.assertEqual(fun(self.array), 0.0)

    def test_schumer_steiglitz(self):
        """Test the schumer steiglitz function."""
        fun = get_problem('schumer_steiglitz', self.dimension, -100, 100)
        self.assertEqual(fun(self.array), 0.0)

    def test_salomon(self):
        """Test the salomon function."""
        fun = get_problem('salomon', self.dimension, -100.0, 100.0)
        self.assertEqual(fun(self.array), 0.0)

    def test_quintic(self):
        """Test the quintic function."""
        fun = get_problem('quintic', self.dimension, -10.0, 10.0)
        self.assertEqual(fun(self.array6), 0.0)

    def test_quintic2(self):
        """Test the quintic function."""
        fun = get_problem('quintic', self.dimension, -10.0, 10.0)
        self.assertEqual(fun(self.array7), 0.0)

    def test_pinter(self):
        """Test the pinter function."""
        fun = get_problem('pinter', self.dimension, -10.0, 10.0)
        self.assertEqual(fun(self.array), 0.0)

    def test_alpine1(self):
        """Test the alpine 1 function."""
        fun = get_problem('alpine1', self.dimension, -10.0, 10.0)
        self.assertEqual(fun(self.array), 0.0)

    def test_alpine2(self):
        """Test the alpine 2 function."""
        fun = get_problem('alpine2', self.dimension, 0.0, 10.0)
        self.assertEqual(fun(self.array8), pow(2.8081311800070053291, self.dimension))

    def test_chung_reynolds(self):
        """Test the chung reynolds function."""
        fun = get_problem('chung_reynolds', self.dimension, -100, 100)
        self.assertEqual(fun(self.array), 0.0)

    def test_csendes(self):
        """Test the csendes function."""
        fun = get_problem('csendes', self.dimension, -1.0, 1.0)
        self.assertEqual(fun(self.array), 0.0)

    def test_bent_cigar(self):
        """Test the bent cigar function."""
        fun = get_problem('bent_cigar', 2, -100, 100)
        self.assertAlmostEqual(fun(np.zeros(2)), 0.0, delta=1e-4)

    def test_discus(self):
        """Test the discus function."""
        fun = get_problem('discus', self.dimension, -100, 100)
        self.assertAlmostEqual(fun(self.array10), 1000054.0, delta=1e-4)

    def test_elliptic(self):
        """Test the elliptic function."""
        fun = get_problem('elliptic', self.dimension, -100, 100)
        self.assertAlmostEqual(fun(self.array10), 5129555.351959938, delta=2e6)

    def test_expanded_griewank_plus_rosenbrock(self):
        """Test the expanded griewank plus rosenbrock function."""
        fun = get_problem('expanded_griewank_plus_rosenbrock', self.dimension, -100, 100)
        self.assertAlmostEqual(fun(self.array), 2.2997, delta=1e2)

    def test_expanded_schaffer(self):
        """Test the expanded schaffer function."""
        fun = get_problem('expanded_schaffer', self.dimension, -100, 100)
        self.assertAlmostEqual(fun(self.array10), 2.616740208857464, delta=1e-4)

    def test_schaffer_n2(self):
        """Test the schaffer n. 2 function."""
        fun = get_problem('schaffer2', lower=-100, upper=100)
        self.assertAlmostEqual(fun(self.array10[:2]), 0.02467, delta=1e-4)

    def test_schaffer_n4(self):
        """Test the schaffer n. 4 function."""
        fun = get_problem('schaffer4', lower=-100, upper=100)
        self.assertAlmostEqual(fun(self.array10[:2]), 0.97545, delta=1e-4)

    def test_hgbat(self):
        """Test the hgbat function."""
        fun = get_problem('hgbat', self.dimension, -100, 100)
        self.assertAlmostEqual(fun(self.array10), 61.91502622129181, delta=60)

    def test_katsuura(self):
        """Test the katsuura function."""
        fun = get_problem('katsuura', self.dimension, -100, 100)
        self.assertAlmostEqual(fun(self.array10), 3837.4739882594373, delta=4000)

    def test_modified_schwefel(self):
        """Test the modified schwefel function."""
        fun = get_problem('modified_schwefel', self.dimension, -100, 100)
        self.assertAlmostEqual(fun(self.array10), 6.9448853328785844, delta=350)

    def test_weierstrass(self):
        """Test the weierstrass function."""
        fun = get_problem('weierstrass', self.dimension, -100, 100)
        self.assertAlmostEqual(fun(self.array10), 0.0, delta=1e-4)

    def test_happy_cat(self):
        """Test the happy cat function."""
        fun = get_problem('happy_cat', self.dimension, alpha=0.125)
        self.assertAlmostEqual(fun(self.array10), 15.1821333, delta=1e-4)

    def test_qing(self):
        """Test the qing function."""
        fun = get_problem('qing', self.dimension, -500, 500)
        self.assertAlmostEqual(fun(self.array10), 584.0, delta=1e-4)

    def test_ridge(self):
        """Test the ridge function."""
        fun = get_problem('ridge', dimension=self.dimension, lower=-64, upper=64)
        self.assertAlmostEqual(fun(self.array10), 371.0, delta=1e-4)

    def test_michalewicz(self):
        """Test the michalewicz function."""
        fun = get_problem('michalewicz', dimension=2, lower=0, upper=np.pi)
        self.assertAlmostEqual(fun(np.asarray([2.20, 1.57])), -1.8013, delta=1e-3)

    def test_levy(self):
        """Test the levy function."""
        fun = get_problem('levy', dimension=2, lower=0, upper=np.pi)
        self.assertAlmostEqual(fun(np.ones(2)), 0.0)

    def test_sphere2(self):
        """Test the sphere 2 function."""
        fun = get_problem('sphere2', dimension=2, lower=-1, upper=1)
        self.assertAlmostEqual(fun(np.zeros(2)), 0.0)

    def test_sphere3(self):
        """Test the sphere 3 function."""
        fun = get_problem('sphere3', dimension=2, lower=-65.536, upper=65.536)
        self.assertAlmostEqual(fun(np.zeros(2)), 0.0)

    def test_trid(self):
        """Test the trid function."""
        fun = get_problem('trid', dimension=2)
        self.assertAlmostEqual(fun(np.array([2.0, 2.0])), -2.0)

    def test_perm(self):
        """Test the perm function."""
        fun = get_problem('perm', dimension=2)
        self.assertAlmostEqual(fun(np.array([1.0, 0.5])), 0.0)

    def test_zakharov(self):
        """Test the zakharov function."""
        fun = get_problem('zakharov', 2, -5, 10)
        self.assertAlmostEqual(fun(np.zeros(2)), 0.0)

    def test_dixon_price(self):
        """Test the dixon price function."""
        fun = get_problem('dixon_price', 2, -10, 10)
        solution = np.array([1.0, 0.70710678])
        self.assertAlmostEqual(fun(solution), 0.0)

    def test_powell(self):
        """Tests the powell function."""
        fun = get_problem('powell', dimension=2, lower=-4, upper=5)
        self.assertAlmostEqual(fun(np.zeros(2)), 0.0)

    def test_cosine_mixture(self):
        """Test the cosine mixture function."""
        fun = get_problem('cosine_mixture', dimension=2, lower=-1, upper=1)
        self.assertAlmostEqual(fun(np.zeros(2)), -0.2)

    def test_infinity(self):
        """Test the infinity function."""
        infinity = get_problem('infinity', dimension=2, lower=-1, upper=1)
        defaults = np.seterr('raise')
        with self.assertRaises(FloatingPointError):
            infinity(np.zeros(2))
        self.assertAlmostEqual(infinity(np.ones(2)), 5.6829419696157935)
        np.seterr(**defaults)



# encoding=utf8
from niapy.algorithms.basic import GeneticAlgorithm
from niapy.algorithms.basic.ga import two_point_crossover, multi_point_crossover, creep_mutation, roulette_selection, \
    crossover_uros, mutation_uros
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class GATestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = GeneticAlgorithm

    def test_custom(self):
        ga_custom = self.algo(population_size=10, tournament_size=4, mutation_rate=0.05, crossover_rate=0.4, seed=self.seed)
        ga_customc = self.algo(population_size=10, tournament_size=4, mutation_rate=0.05, crossover_rate=0.4, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ga_custom, ga_customc, MyProblem())

    def test_griewank(self):
        ga_griewank = self.algo(population_size=10, tournament_size=4, mutation_rate=0.05, crossover_rate=0.4, seed=self.seed)
        ga_griewankc = self.algo(population_size=10, tournament_size=4, mutation_rate=0.05, crossover_rate=0.4, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ga_griewank, ga_griewankc)

    def test_two_point_crossover_fine_c(self):
        ga_tpcr = self.algo(population_size=10, tournament_size=4, mutation_rate=0.05, crossover_rate=0.4, crossover=two_point_crossover, seed=self.seed)
        ga_tpcrc = self.algo(population_size=10, tournament_size=4, mutation_rate=0.05, crossover_rate=0.4, crossover=two_point_crossover, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ga_tpcr, ga_tpcrc, MyProblem())

    def test_two_point_crossover(self):
        ga_tpcr = self.algo(population_size=10, tournament_size=4, mutation_rate=0.05, crossover_rate=0.4, crossover=two_point_crossover, seed=self.seed)
        ga_tpcrc = self.algo(population_size=10, tournament_size=4, mutation_rate=0.05, crossover_rate=0.4, crossover=two_point_crossover, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ga_tpcr, ga_tpcrc)

    def test_multi_point_crossover_fine_c(self):
        ga_mpcr = self.algo(population_size=10, tournament_size=4, mutation_rate=0.05, crossover_rate=4, crossover=multi_point_crossover, seed=self.seed)
        ga_mpcrc = self.algo(population_size=10, tournament_size=4, mutation_rate=0.05, crossover_rate=4, crossover=multi_point_crossover, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ga_mpcr, ga_mpcrc, MyProblem())

    def test_multi_point_crossover(self):
        ga_mpcr = self.algo(population_size=10, tournament_size=4, mutation_rate=0.05, crossover_rate=4, crossover=multi_point_crossover, seed=self.seed)
        ga_mpcrc = self.algo(population_size=10, tournament_size=4, mutation_rate=0.05, crossover_rate=4, crossover=multi_point_crossover, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ga_mpcr, ga_mpcrc)

    def test_creep_mutation_fine_c(self):
        ga_crmt = self.algo(population_size=10, tournament_size=4, mutation_rate=0.05, crossover_rate=0.4, mutation=creep_mutation, seed=self.seed)
        ga_crmtc = self.algo(population_size=10, tournament_size=4, mutation_rate=0.05, crossover_rate=0.4, mutation=creep_mutation, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ga_crmt, ga_crmtc, MyProblem())

    def test_creep_mutation(self):
        ga_crmt = self.algo(population_size=10, tournament_size=4, mutation_rate=0.05, crossover_rate=0.4, mutation=creep_mutation, seed=self.seed)
        ga_crmtc = self.algo(population_size=10, tournament_size=4, mutation_rate=0.05, crossover_rate=0.4, mutation=creep_mutation, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ga_crmt, ga_crmtc)

    def test_roulette_selection_c(self):
        ga_crmt = self.algo(population_size=10, tournament_size=4, mutation_rate=0.05, crossover_rate=0.4, selection=roulette_selection, seed=self.seed)
        ga_crmtc = self.algo(population_size=10, tournament_size=4, mutation_rate=0.05, crossover_rate=0.4, selection=roulette_selection, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ga_crmt, ga_crmtc, MyProblem())

    def test_roulette_selection(self):
        ga_crmt = self.algo(population_size=10, tournament_size=4, mutation_rate=0.05, crossover_rate=0.4, selection=roulette_selection, seed=self.seed)
        ga_crmtc = self.algo(population_size=10, tournament_size=4, mutation_rate=0.05, crossover_rate=0.4, selection=roulette_selection, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ga_crmt, ga_crmtc)

    def test_crossover_uros_c(self):
        ga_crmt = self.algo(population_size=10, tournament_size=4, mutation_rate=0.05, crossover_rate=0.4, crossover=crossover_uros, seed=self.seed)
        ga_crmtc = self.algo(population_size=10, tournament_size=4, mutation_rate=0.05, crossover_rate=0.4, crossover=crossover_uros, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ga_crmt, ga_crmtc, MyProblem())

    def test_crossover_uros(self):
        ga_crmt = self.algo(population_size=10, tournament_size=4, mutation_rate=0.05, crossover_rate=0.4, crossover=crossover_uros, seed=self.seed)
        ga_crmtc = self.algo(population_size=10, tournament_size=4, mutation_rate=0.05, crossover_rate=0.4, crossover=crossover_uros, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ga_crmt, ga_crmtc)

    def test_mutation_uros_c(self):
        ga_crmt = self.algo(population_size=10, tournament_size=4, mutation_rate=0.05, crossover_rate=0.4, mutation=mutation_uros, seed=self.seed)
        ga_crmtc = self.algo(population_size=10, tournament_size=4, mutation_rate=0.05, crossover_rate=0.4, mutation=mutation_uros, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ga_crmt, ga_crmtc, MyProblem())

    def test_mutation_uros(self):
        ga_crmt = self.algo(population_size=10, tournament_size=4, mutation_rate=0.05, crossover_rate=0.4, mutation=mutation_uros, seed=self.seed)
        ga_crmtc = self.algo(population_size=10, tournament_size=4, mutation_rate=0.05, crossover_rate=0.4, mutation=mutation_uros, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, ga_crmt, ga_crmtc)

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



# encoding=utf8
from niapy.algorithms.other import MultipleTrajectorySearch, MultipleTrajectorySearchV1
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class MTSTestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = MultipleTrajectorySearch

    def test_custom(self):
        mts_custom = self.algo(population_size=10, C_a=2, C_r=0.5, seed=self.seed)
        mts_customc = self.algo(population_size=10, C_a=2, C_r=0.5, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, mts_custom, mts_customc, MyProblem(), max_iters=100)

    def test_griewank(self):
        mts_griewank = self.algo(population_size=10, C_a=5, C_r=0.5, seed=self.seed)
        mts_griewankc = self.algo(population_size=10, C_a=5, C_r=0.5, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, mts_griewank, mts_griewankc, max_iters=100)


class MTSv1TestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = MultipleTrajectorySearchV1

    def test_custom(self):
        mts_custom = self.algo(population_size=10, C_a=2, C_r=0.5, seed=self.seed)
        mts_customc = self.algo(population_size=10, C_a=2, C_r=0.5, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, mts_custom, mts_customc, MyProblem())

    def test_griewank(self):
        mts_griewank = self.algo(population_size=10, C_a=5, C_r=0.5, seed=self.seed)
        mts_griewankc = self.algo(population_size=10, C_a=5, C_r=0.5, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, mts_griewank, mts_griewankc)

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



from niapy.algorithms.basic import FireflyAlgorithm
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class FATestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = FireflyAlgorithm

    def test(self):
        fa = self.algo(population_size=10, alpha=0.5, beta0=0.2, gamma=1.0, seed=self.seed)
        fac = self.algo(population_size=10, alpha=0.5, beta0=0.2, gamma=1.0, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, fa, fac, MyProblem())

    def test_griewank(self):
        fa_griewank = self.algo(population_size=10, alpha=0.5, beta0=0.2, gamma=1.0, seed=self.seed)
        fa_griewankc = self.algo(population_size=10, alpha=0.5, beta0=0.2, gamma=1.0, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, fa_griewank, fa_griewankc)

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3



# encoding=utf8

from niapy.algorithms.basic import HarmonySearch, HarmonySearchV1
from niapy.tests.test_algorithm import AlgorithmTestCase, MyProblem


class HSTestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = HarmonySearch

    def test_custom(self):
        hs_costom = self.algo(population_size=10, seed=self.seed)
        hs_costomc = self.algo(population_size=10, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, hs_costom, hs_costomc, MyProblem())

    def test_griewank(self):
        hs_griewank = self.algo(population_size=10, seed=self.seed)
        hs_griewankc = self.algo(population_size=10, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, hs_griewank, hs_griewankc)


class HSv1TestCase(AlgorithmTestCase):
    def setUp(self):
        AlgorithmTestCase.setUp(self)
        self.algo = HarmonySearchV1

    def test_custom(self):
        hs_costom = self.algo(population_size=10, seed=self.seed)
        hs_costomc = self.algo(population_size=10, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, hs_costom, hs_costomc, MyProblem())

    def test_griewank(self):
        hs_griewank = self.algo(population_size=10, seed=self.seed)
        hs_griewankc = self.algo(population_size=10, seed=self.seed)
        AlgorithmTestCase.test_algorithm_run(self, hs_griewank, hs_griewankc)

# vim: tabstop=3 noexpandtab shiftwidth=3 softtabstop=3
